const { BlobServiceClient, StorageSharedKeyCredential } = require('@azure/storage-blob');
const { AZURE } = require('../../utils/consts');
const { setProxy } = require('../cloud-manager/config-operations');
const getLogger = require('../../utils/logger');

const logger = getLogger();

async function getBlobServiceClient(storageAccount, storageAccountKey) {
    logger.debug('Getting blob service client');
    await setProxy(AZURE);
    const sharedKeyCredential = new StorageSharedKeyCredential(storageAccount, storageAccountKey);

    return new BlobServiceClient(
        `https://${storageAccount}.blob.core.windows.net`,
        sharedKeyCredential
    );
}

async function listBlobContainers(storageAccount, storageAccountKey) {
    logger.info('Listing blob containers:', storageAccount);

    const blobServiceClient = await getBlobServiceClient(storageAccount, storageAccountKey);
    const containers = [];
    const iter = blobServiceClient.listContainers();

    for await (const container of iter) {
        containers.push(container.name);
    }

    return containers;
}

async function createBlobContainer(storageAccount, storageAccountKey, containerName) {
    logger.info('Creating blob container:', { storageAccount, containerName });
    const blobServiceClient = await getBlobServiceClient(storageAccount, storageAccountKey);

    await blobServiceClient.createContainer(containerName);
}

module.exports = {
    listBlobContainers,
    createBlobContainer
};
