const { ResourceGroups, ResourceManagementClient } = require('@azure/arm-resources');
const getCredentials = require('../cloud-manager/credentials-operations');
const { getConfigIdentity } = require('../cloud-manager/config-operations');
const { setProxy } = require('../cloud-manager/config-operations');
const getLogger = require('../../utils/logger');
const { AZURE } = require('../../utils/consts');

const logger = getLogger();

async function getResourceGroupsClient() {
    logger.debug('Getting resource management client');
    const credentials = await getCredentials(AZURE);
    await setProxy(AZURE);
    const { subscription } = await getConfigIdentity();
    const client = new ResourceManagementClient(credentials, subscription);

    return new ResourceGroups(client);
}

async function createResourceGroup(resourceGroupName, location) {
    logger.info('Creating resource group:', { resourceGroupName, location });
    const resourceGroups = await getResourceGroupsClient();

    return resourceGroups.createOrUpdate(resourceGroupName, { location });
}

async function listResourceGroups() {
    logger.info('List resource groups');
    const resourceGroupsClient = await getResourceGroupsClient();
    const resourceGroups = await resourceGroupsClient.list();
    return resourceGroups;
}

module.exports = { createResourceGroup, listResourceGroups };
