// proxy-agent should be used instead of https-proxy-agent
// this issue prevents us from using proxy-agent:
// https://github.com/TooTallNate/node-proxy-agent/issues/51
// more info about it:
// https://github.com/TooTallNate/node-agent-base/issues/35
// https://github.com/sindresorhus/got/issues/951
const HttpsProxyAgent = require('https-proxy-agent');
const { URL } = require('url');
const gotInstance = require('../../utils/got');
const {
    CREDENTIALS_SERVICE_SERVER_ADDRESS, AWS, AZURE, GCP
} = require('../../utils/consts');
const getLogger = require('../../utils/logger');

const API_PATH_CONFIG_MANAGER = '/config';

const logger = getLogger();

let identity;

async function getConfigIdentity() {
    logger.debug('Getting config identity');
    if (!identity) {
        identity = await gotInstance.get(`${CREDENTIALS_SERVICE_SERVER_ADDRESS}${API_PATH_CONFIG_MANAGER}/identity`);
        logger.info('Identity received:', identity);
    }
    return identity;
}

async function getProxy() {
    const { url, userName, password } = await gotInstance.get(`${CREDENTIALS_SERVICE_SERVER_ADDRESS}${API_PATH_CONFIG_MANAGER}/proxy`);
    if (url === '') {
        logger.info('No proxy configured');
    } else {
        const proxyUrl = new URL(url);
        if (userName && password) {
            proxyUrl.username = userName;
            proxyUrl.password = password;
        }
        return proxyUrl;
    }
}

async function setProxy(provider) {
    logger.debug('Setting proxy:', provider);
    const { url, userName, password } = await gotInstance.get(`${CREDENTIALS_SERVICE_SERVER_ADDRESS}${API_PATH_CONFIG_MANAGER}/proxy`);

    if (url === '') {
        logger.debug('No proxy configured');
    } else {
        logger.debug('Proxy is configured:', { url, userName, password });
        const proxyUrl = new URL(url);
        if (userName && password) {
            proxyUrl.username = userName;
            proxyUrl.password = password;
        }

        switch (provider) {
            case AWS:
                return { agent: new HttpsProxyAgent(proxyUrl.toString()) };
            case AZURE: // AZURE & GCP SDK supports HTTP_PROXY environment variable
            case GCP: {
                process.env.HTTP_PROXY = proxyUrl.toString();
                break;
            }
            default:
                return undefined;
        }
    }
}

module.exports = { getConfigIdentity, setProxy, getProxy };
