const {
    getAwsBucketsSchema, createAwsBucketSchema, updateAwsTierLevelSchema,
    getAwsRegionsSchema, describeAwsTierLevelSchema
} = require('../validation/routes-schema-validation');
const {
    getBucketLifecycleConfiguration, putBucketLifecycleConfiguration
} = require('../lib/aws/s3');
const { listS3Buckets, createS3Bucket } = require('../operations/aws-operations');
const getAwsRegions = require('../lib/aws/ec2');

const API_PATH_AWS = '/aws';

function awsRoutes(fastify) {
    fastify.get(`${API_PATH_AWS}/buckets`, { schema: getAwsBucketsSchema }, async () => listS3Buckets());

    fastify.post(`${API_PATH_AWS}/buckets`, { schema: createAwsBucketSchema }, async request => {
        const { body: { name, region } } = request;
        await createS3Bucket(name, region);
        return { region, name };
    });

    fastify.get(`${API_PATH_AWS}/regions`, { schema: getAwsRegionsSchema }, async () => getAwsRegions());

    fastify.get(`${API_PATH_AWS}/buckets/storage-class`, { schema: describeAwsTierLevelSchema }, async request => {
        const { query: { bucket } } = request;
        return getBucketLifecycleConfiguration(bucket);
    });

    fastify.put(`${API_PATH_AWS}/buckets/storage-class`, { schema: updateAwsTierLevelSchema }, async (request, reply) => {
        const { body: { bucket, storageClass } } = request;
        await putBucketLifecycleConfiguration(bucket, storageClass);
        reply.code(200).send();
    });
}

module.exports = awsRoutes;
