const {
    updateGcpTierLevelSchema, getGcpBucketsSchema,
    createGcpBucketSchema, getGcpRegionsSchema, getGcpProjectsSchema
} = require('../validation/routes-schema-validation');
const { createBucket, getBuckets, setStorageClass } = require('../lib/gcp/storage');
const getRegions = require('../lib/gcp/compute');
const getProjects = require('../lib/gcp/resource');

const API_PATH_GCP = '/gcp';

function gcpRoutes(fastify) {
    fastify.get(`${API_PATH_GCP}/buckets`, { schema: getGcpBucketsSchema }, async () => getBuckets());

    fastify.post(`${API_PATH_GCP}/buckets`, { schema: createGcpBucketSchema }, async request => {
        const { body: { name, region } } = request;
        return createBucket(name, region);
    });

    fastify.put(`${API_PATH_GCP}/buckets/storage-class`, { schema: updateGcpTierLevelSchema }, async (request, reply) => {
        const { body: { bucket, storageClass } } = request;
        await setStorageClass(bucket, storageClass);
        reply.code(200).send();
    });

    fastify.get(`${API_PATH_GCP}/regions`, { schema: getGcpRegionsSchema }, async () => getRegions());

    fastify.get(`${API_PATH_GCP}/projects`, { schema: getGcpProjectsSchema }, async () => getProjects());
}

module.exports = gcpRoutes;
