const config = require('config');
const { join } = require('path');

const ZAPI_REQUEST_DIR = join(process.cwd(), './resources/zapi/requests'); // eslint-disable-line import/no-dynamic-require
const VERSION = require(join(process.cwd(), './package.json')).version; // eslint-disable-line import/no-dynamic-require

// Services URLs
const CREDENTIALS_SERVICE_SERVER_ADDRESS = config.get('services-urls.credentials-service');

// Cloud Providers
const AWS = 'AWS';
const AZURE = 'AZURE';
const GCP = 'GCP';
const SGWS = 'SGWS';

const S3 = 'S3';

// Tiering Policies
const ALL = 'all';
const SNAPSHOT_ONLY = 'snapshot_only';
const AUTO = 'auto';
const BACKUP = 'backup';
const NONE = 'none';

// AWS
// Default Values
const DEFAULT_AWS_REGION = 'us-east-1';

// Regions
const AWS_REGIONS = {
    'us-east-2': 'US East (Ohio)',
    'us-east-1': 'US East (N. Virginia)',
    'us-west-1': 'US West (N. California)',
    'us-west-2': 'US West (Oregon)',
    'ap-south-1': 'Asia Pacific (Mumbai)',
    'ap-northeast-3': 'Asia Pacific (Osaka-Local)',
    'ap-northeast-2': 'Asia Pacific (Seoul)',
    'ap-southeast-1': 'Asia Pacific (Singapore)',
    'ap-southeast-2': 'Asia Pacific (Sydney)',
    'ap-northeast-1': 'Asia Pacific (Tokyo)',
    'ca-central-1': 'Canada (Central)',
    'cn-north-1': 'China (Beijing)',
    'cn-northwest-1': 'China (Ningxia)',
    'eu-central-1': 'EU (Frankfurt)',
    'eu-west-1': 'EU (Ireland)',
    'eu-west-2': 'EU (London)',
    'eu-west-3': 'EU (Paris)',
    'eu-north-1': 'EU (Stockholm)',
    'sa-east-1': 'South America (São Paulo)',
    'us-gov-east-1': 'AWS GovCloud (US-East)',
    'us-gov-west-1': 'AWS GovCloud (US)',
    'me-south-1': 'Middle East (Bahrain)',
    'ap-east-1': 'Asia Pacific (Hong Kong)',
    US: 'US East (N. Virginia)'
};

// Storage class
const STANDARD_IA = 'STANDARD_IA';
const ONE_ZONE_IA = 'ONEZONE_IA';
const INTELLIGENT = 'INTELLIGENT_TIERING';
const STANDARD_AWS = 'STANDARD';

const AWS_STORAGE_CLASSES_TRANSLATOR = {
    // from tiering to AWS
    [STANDARD_IA]: 'STANDARD_IA',
    [ONE_ZONE_IA]: 'ONEZONE_IA',
    [INTELLIGENT]: 'INTELLIGENT_TIERING',
    // from AWS to tiering
    STANDARD_IA,
    ONEZONE_IA: ONE_ZONE_IA,
    INTELLIGENT_TIERING: INTELLIGENT
};

// GCP
// Regions
const GCP_REGIONS = {
    'northamerica-northeast1': 'Canada (Montr\u00E9al)',
    'us-central1': 'US Central (Iowa)',
    'us-east1': 'US East (South Carolina)',
    'us-east4': 'US East (Northern Virginia)',
    'us-west1': 'US West (Oregon)',
    'us-west2': 'US West (Los Angeles)',
    'southamerica-east-1': 'South America (S\u00E3o Paulo)',
    'europe-north1': 'EU West (Finland)',
    'europe-west1': 'EU West (Belgium)',
    'europe-west2': 'EU West (London)',
    'europe-west3': 'EU West (Frankfurt)',
    'europe-west4': 'EU West (Netherlands)',
    'europe-west6': 'EU West (Zürich)',
    'asia-east1': 'Asia East (Taiwan)',
    'asia-east2': 'Asia East (Hong Kong)',
    'asia-northeast1': 'Asia North-East (Tokyo)',
    'asia-northeast2': 'Asia North-East (Osaka)',
    'asia-south1': 'Asia South (Mumbai)',
    'asia-southeast1': 'Asia South-East (Singapore)',
    'australia-southeast1': 'Australia (Sydney)',
    asia: 'Asia',
    eu: 'EU',
    us: 'US'
};

// Storage class
// standard also relevant
const NEARLINE = 'nearline';
const COLDLINE = 'coldline';
const ARCHIVE = 'archive';
const MULTI_REGION = 'multi_regional';
const REGIONAL = 'regional';
const STANDARD = 'standard'; // relevant to also GCP

// Object store config
const OBJECT_STORE_CONFIG_TYPE = {
    [AWS]: 'aws_s3',
    [AZURE]: 'azure_cloud',
    [GCP]: 'googlecloud',
    [SGWS]: 'sgws'
};

module.exports = {
    ZAPI_REQUEST_DIR,
    VERSION,
    CREDENTIALS_SERVICE_SERVER_ADDRESS,
    AWS,
    AZURE,
    GCP,
    SGWS,
    ALL,
    SNAPSHOT_ONLY,
    AUTO,
    BACKUP,
    NONE,
    DEFAULT_AWS_REGION,
    AWS_REGIONS,
    STANDARD_IA,
    ONE_ZONE_IA,
    INTELLIGENT,
    STANDARD_AWS,
    AWS_STORAGE_CLASSES_TRANSLATOR,
    GCP_REGIONS,
    NEARLINE,
    COLDLINE,
    ARCHIVE,
    MULTI_REGION,
    REGIONAL,
    STANDARD,
    OBJECT_STORE_CONFIG_TYPE,
    S3
};
