const { groupBy } = require('lodash');
const Promise = require('bluebird');
/* eslint-disable */
let getResourcesByAccount;
if (process.env.IS_SIMULATOR) {
  ({ getResourcesByAccount } = require('../src/lib/cloud-manager/multi-tenancy'));
} else {
  ({ getResourcesByAccount } = require('../lib/cloud-manager/multi-tenancy'));
}
let getLogger;
if (process.env.IS_SIMULATOR) {
  (getLogger  = require('../src/utils/logger/logger'));
} else {
    ( getLogger  = require('../utils/logger/logger'));
}

const logger = getLogger();
module.exports = {
  async up(db, client) {
    const clusters = db.collection('clusters');

    const clustersFromCollection = await clusters.find().toArray();
    const clustersByAccountId = groupBy(clustersFromCollection, 'accountId');

    await Promise.map(Object.keys(clustersByAccountId), (async accountId => {
      try {
        const resources = await getResourcesByAccount(accountId, true);
        const onprems = resources.filter(resource => resource.resourceClass === 'ON_PREM');
        const clustersToUpdate = clustersByAccountId[accountId];
        await Promise.all(clustersToUpdate.map(async cluster => {
          logger.info('<<<<<<<<<<', cluster);
          const {clusterId, accountId} = cluster;
          const resource = onprems.find(resource => {
            logger.info('>>>>>>>>', resource.resourceIdentifier, clusterId);
            return resource.resourceIdentifier === clusterId
          });
          if (resource) {
            await clusters.updateOne({clusterId, accountId}, {$set: {agentId: resource.agentId}})
          }
        }));
      } catch (err) {
        logger.error('ERROR', err);
      }
    }));
  },

  async down(db, client) {
    const clusters = db.collection('clusters');
    await clusters.updateMany({}, { $unset: { agentId: ''} });
  }
};
