const { gql } = require('apollo-server');

const typeDefs = gql`

    scalar IpAddress
    
    scalar HostName
    
    interface BucketG {
        name:String!
    }
    
    type CloudBucket implements BucketG {
        name:String!
        region:Region!
    }
    
  type SGBucket implements BucketG {
        name:String!  
  }
  
  type AzureContainer implements BucketG {
        name:String!
        region: Region!
        storageAccount:String!
        resourceGroup:String!       
  }
    
    
    type ClusterStatus {
        status: CLUSTER_STATUS!
        message: String
    }
    
    type OntapClusterProperties {
        ontapVersion: String!
        clusterAddress: IpAddress!
        clusterUuid: String!
    }
    
    enum IDR_STATUS {
     ON
     OFF
    }
    
    enum CLUSTER_STATUS {
        FAILED
        ON
        UNKNOWN
        NO_TIERING
    }
    
    enum RESOURCE_TYPE {
        CVO
        ON_PREM
    }
    
    enum TIERING_STATUS{
        DONE
        PROGRESS
        FAILED
    }
    
    enum FREE_TRIAL_STATUS{
        PRE,
        STARTED
        EXPIRED
    }
    
    
    type PerformanceCapacity{
        inactiveCapacity: Float
        activeCapacity: Float
        isEstimatedInactiveCapacity: Boolean
        usedPerformanceCapacity: Float
        snapshotsUsedSize: Float
    }
    
    type SavingInformation {
        cost: Int
        capacity: Float
    }
    
    type CapacityInformation{
        usedPerformanceAndTieredCapacity: Float 
        performanceCapacity: PerformanceCapacity
        savingOpportunity: SavingInformation
        allocatedCapacity : Float
    }
    
    type TierInformation{
        bucketName: String!
        providerType: String!
        objectStoreName: String!
        regionName: String
        tierLevel: STORAGE_CLASS
        currentSavings: SavingInformation
    }
    
    type Policy{
        name: TIERING_POLICY!
        count: Int
        savingOpportunity: SavingInformation
        isEstimated: Boolean
        supported: PolicySupport
    }
    
    type PolicySupport {
        isSupported: Boolean!
        reason: String
    }

    type ClusterVolumes{
        tieredVolumes: Int,
        eligibleVolumes : Int
        totalVolumes: Int
        supportedPolicies:[Policy]
    }
    
    type Stats{
        tieredCapacity: Float!
        numberOfActiveClusters : Int!
        numberOfClusters: Int!
    }
    
     type FailedVolumes {
        name: String!
        svmName: String!
        reason: String!
    }
        
    
    type ClusterLicenseInfo {
        shouldEnforce : Boolean
        byolCapacity: Float
        currentCapacity: Float
        freeTrialStatus: FREE_TRIAL_STATUS
        subscriptionStatus: SubscriptionStatus
        hasBYOL: Boolean
        provider: CLOUD_PROVIDERS
    }
        
    type Cluster {
        clusterId: ID!
        name: String
        ontapClusterProperties: OntapClusterProperties
        status: ClusterStatus
        capacityInformation: CapacityInformation
        tierInformation : TierInformation
        volumes : ClusterVolumes,
        agentCloudProvider: CLOUD_PROVIDERS
        agentId: ID
        agentSystemId:ID
        resourceType : RESOURCE_TYPE
        licenseInfo: ClusterLicenseInfo
        isEligibleForTiering: Boolean
        isEligibleForTieringReason: String
    }

    type EmptyResult {
        status: String
    }

    input VolumeIdentifier {
        name: String!
        svmName: String!
    }
       
    input Keys {
        accessKey: String!
        secretKey: String!    
    }

    input DiscoverParams {
        clusterAddress: IpAddress!
        clusterUserName: String!
        clusterPassword: String!
        agentId: String!
    }
    
    input AutoDiscoverParams {
        accountId:ID,
        clusterAddress: IpAddress!
        clusterUserName: String!
        clusterPassword: String!
    }
    
    input VolumeProperties {
        name: String!
        svmName: String!
        tieringPolicy: TIERING_POLICY
        minimumCoolingDays: Int    
    }

    
    input VerifyPermissionsParams {
        credentials:Keys
        cloudProvider:CLOUD_PROVIDERS!
        accountId:ID
        bucket:String
        region: String
    }
    
    input CreateSgwsBucket{
        clusterId: ID
        accountId:ID
        agentId:ID
        name:String!
        host:HostName!
        port:Int
        credentials:Keys!        
    }
    
    input CreateAwsBucket {
        clusterId:ID
        accountId:ID
        agentId:ID
        name:String!
        region:String!
    }  
    
    input CreateGcpBucket {
        clusterId:ID
        agentId:ID
        accountId:ID
        name:String!
        region:String!
    }   
    
        
    input CreateAzureContainer{
        clusterId: ID
        agentId:ID
        accountId:ID
        name:String!
        resourceGroup: String!
        storageAccount: String!    
    }
    
     input CreateBucketGInput {
      cloudProvider : CLOUD_PROVIDERS!
      aws:CreateAwsBucket
      gcp: CreateGcpBucket
      sgws:CreateSgwsBucket
      azure: CreateAzureContainer
     }
          
        
    input S3SetupTiering{
        clusterId: ID!
        agentId:ID,
        workspaceId:ID
        accountId:ID
        ipSpace: String!
        credentials:Keys!
        bucket:String!
        region: String!
    }
    
    input GcpSetupTiering {
        clusterId: ID!
        agentId:ID
        accountId:ID
        workspaceId:ID
        ipSpace: String!
        credentials:Keys!
        bucket:String!
        region: String!
    }
    
    input AzureSetupTiering {
        clusterId: ID!
        agentId:ID
        accountId:ID
        workspaceId:ID
        ipSpace: String!
        azureStorageAccount: String
        azureResourceGroup: String
        bucket:String
        region:String
    }
    
    input SgwsSetupTiering{
       clusterId: ID!
       agentId:ID
       accountId:ID
       workspaceId:ID
       ipSpace: String!
       bucket: String!
       port:Int
       host:HostName!
       credentials: Keys!
    }
    
    input ClusterTieringSetupInput{
        cloudProvider:CLOUD_PROVIDERS!
        aws : S3SetupTiering 
        gcp: GcpSetupTiering
        azure:AzureSetupTiering
        sgws: SgwsSetupTiering
    }
    
    input applyByolLicenseInput{
        nssUserName: String!
        nssPassword: String!
        clusterId : ID!
        serialNumber: String!
        accountId: ID!
        agentId: ID
        workspaceId:ID
    }
    
    enum STORAGE_CLASS{
        standard
        standard_ia
        ia_single
        intelligent
        hot
        cool
        coldline
        nearline
    }
    
    enum CLUSTER_CONNECTIVITY_STATUS {
        FAILED
        SUCCESS
    }
    
    input ModifyVolumes {
       clusterId: ID!
       agentId:ID
       accountId:ID
       workspaceId:ID
       volumeProperties: [VolumeProperties!]!
    }
    
    input AggregateProperties {
        name:String!
        idr: IDR_STATUS
        tieringFullnessThreshold:Int
    }
    
    input ModifyAggregates {
        clusterId : ID!
        agentId:ID
        accountId:ID
        workspaceId:ID
        aggregatesProperties: [AggregateProperties!]!
    }
    
    enum TIERING_POLICY {
        none
        auto
        snapshot_only
        backup
        all
    }
    
    input ChangeTierLevelParam {
        clusterId: ID!
        bucket: String
        level: STORAGE_CLASS!
        storageAccount: String
        resourceGroup: String
        cloudProvider: CLOUD_PROVIDERS!
    }

    enum AZURE_STORAGE_CLASS{
       hot,
       cool
    }
    
    enum AWS_STORAGE_CLASS{
      standard,
        standard_ia
        ia_single
        intelligent
    }

    enum GCP_STORAGE_CLASS{
      coldline
      nearline
      standard
    }
    
   
    
    input ChangeAwsTierLevelRequest {
        clusterId: ID
        agentId:ID,
        accountId:ID
        bucket: String!
        level: AWS_STORAGE_CLASS!
    }
    
    input ChangeGCPTierLevelRequest {
        clusterId: ID
        agentId:ID
        accountId:ID
        bucket: String!
        level: GCP_STORAGE_CLASS!
    }

 input ChangeAzureTierLevelRequest {
        clusterId: ID
        agentId:ID
        accountId:ID
        level: AZURE_STORAGE_CLASS!
        storageAccount: String!
        resourceGroup: String!
    }
    
    input ChangeTierLevelGInput {
        cloudProvider:CLOUD_PROVIDERS!
        aws:ChangeAwsTierLevelRequest
        gcp: ChangeGCPTierLevelRequest
        azure:ChangeAzureTierLevelRequest
    }

 input ChangeAwsTierLevelParam {
        clusterId: ID!
        bucket: String!
        level: STORAGE_CLASS!
    }

    
    type VolumeSupportedSettings {
        tieringPolicy : TIERING_POLICY
        minimumCoolingDays:Int
        noMinimumCoolingDaysReason : String
    }
    
    type Error{
       reason: String
       name: String
       svmName: String
    }
   
    
    type ModifyVolumesResponse {
        data: [Volume]
        errors: [Error]
    }
    
    type ModifyAggregatesResponse {
        data: [Aggregate]
        errors: [Error]    
    }
  
    type Volume {
        name: String!
        svmName: String!
        aggregateName: String
        capacity: Float
        inactiveCapacity: Float
        inactiveCapacityPercent : Int
        tieringPolicy: TIERING_POLICY
        tieredCapacity: Float
        isEligibleForTiering : Boolean!
        tieringRestrictionReason: String
        isEstimatedInactiveCapacity: Boolean!
        usedPerformanceCapacity : Float
        usedPerformanceAndTieredCapacity: Float
        snapshotsUsedSize: Float
        isTiered: Boolean!
        supportedSettings: [VolumeSupportedSettings]!
        minimumCoolingDays: Int
        state:String
    }
    
    enum FEATURE_STATE{
        not_supported
        editable
        read_only
    }
    
    type AggregateSupportedSettings{
        idr:IDR_STATUS
        noIdrReason:String
        idrState: FEATURE_STATE
        tieringFullnessThresholdState:FEATURE_STATE
        tieringFullnessThreshold:Int
        noTieringFullnessThreshold:String
    }
    
    type Aggregate {
        name: String!
        capacity: Float
        usedPerformanceCapacity : Float
        inactiveCapacity: Float
        inactiveCapacityPercent : Int
        idr: IDR_STATUS
        tieringFullnessThreshold:Int
        tieredCapacity: Float
        isEligibleForTiering : Boolean!
        tieringRestrictionReason: String
        supportedSettings: AggregateSupportedSettings!
        isEstimatedInactiveCapacity: Boolean!   
    }
    
    type ClusterConnectivityStatus{
    status:CLUSTER_CONNECTIVITY_STATUS
    reason:String
    }
 
    enum RegistrationStatus{
    not_registered
    registered
    in_progress
    }
    
    type SubscriptionSchema {
    status: SubscriptionStatus
    provider:CLOUD_PROVIDERS
    }

    
    type LicenseInfo {
        accountId : ID!
        subscriptions:[SubscriptionSchema]
        daysLeftForTrial: Int   
    }
    

    type ResourcesResponse {
        total: Int!
        CVO: Int!
        ON_PREM:Int!
    }
    type Region {
        code:String
        name:String
    }
    
    type DiscoverResponse {
        clusterId: ID!
    }
    
     type BucketResponse {
        name:String!
        storageAccount:String
        resourceGroup:String
        region: Region
    }
        
    type SgwsBucketResponse {
        name:String!
    }
    type Bucket {
        name:String!
        region: Region!
    }
    
    type StorageAccount {
        resourceGroup: String
        name: String
        region: Region
    }
    
    type ResourceGroup {
        name: String
    }
    
    type Container{
        name:String!
        region: Region
        storageAccount:String
        resourceGroup:String    
    }
    
    enum AgentStatus {
        pending
        active
        inactive
        unknown
        unsupported
    }
    
    enum CONNECTIVITY_STATUS{
    SUCCESS
    FAILED
    }
    
    enum CLOUD_PROVIDERS {
        AWS
        AZURE
        ONPREM
        GCP
        SGWS
    }

    enum SubscriptionStatus{
        subscribed
        unsubscribed
    }
        
   
    input AwsBucketsRequest {
        accountId:ID
        agentId:ID
        clusterId:ID
    }
    
     input AzureBucketsRequest {
        accountId:ID
        clusterId:ID
        agentId:ID!
        resourceGroupName: ID!
    }
    
     input GcpBucketsRequest {
        accountId:ID
        clusterId:ID
        agentId:ID
    } 
    input SgwsBucketsRequest {
        clusterId:ID
        agentId:ID
        accountId:ID
        host:HostName!
        port:Int
        credentials:Keys!
    }

    input GetBucketsRequest {
        cloudProvider:CLOUD_PROVIDERS
        sgws: SgwsBucketsRequest
        aws : AwsBucketsRequest
        azure: AzureBucketsRequest
        gcp: GcpBucketsRequest
    }

    input RemoveClusterInput {
        accountId:ID
        clusterId:ID
        workspaceId:ID
        agentId:ID
    }
    
    type Query {
        clusters(accountId:ID!, workspaceId:ID!, agentId:ID!): [Cluster]!
        lazyClusters(accountId:ID!, workspaceId:ID!, agentId:ID!):[Cluster]!
        cluster(accountId:ID!, clusterId: ID!, workspaceId:ID, agentId:ID): Cluster
        volumes(accountId:ID, agentId:ID, clusterId: ID!, workspaceId:ID): [Volume]!
        aggregates(accountId:ID, agentId:ID, clusterId: ID!, workspaceId:ID): [Aggregate]!
        regions(cloudProvider:CLOUD_PROVIDERS!, accountId:ID, agentId:ID, clusterId: ID): [Region]!,
        region(cloudProvider:CLOUD_PROVIDERS!, accountId: ID, regionCode: String): Region!,
        bucketsG(request:GetBucketsRequest):[BucketG]
        storageAccounts(accountId:ID, clusterId:ID, agentId:ID!, resourceGroupName: ID!):[StorageAccount]
        ipSpaces(accountId:ID, clusterId: ID!, agentId:ID, workspaceId:ID):[String]
        licenseInfo(accountId:ID): LicenseInfo
        resourceGroups(accountId:ID, clusterId:ID, agentId:ID!):[ResourceGroup]
    }

    type Mutation{
        modifyVolumes(input: ModifyVolumes) : ModifyVolumesResponse
        modifyAggregates(input: ModifyAggregates) : ModifyAggregatesResponse
        removeCluster(input: RemoveClusterInput): EmptyResult
        verifyPermissions(input: VerifyPermissionsParams): EmptyResult
        createBucketG(input: CreateBucketGInput): EmptyResult 
        changeTierLevelG(input: ChangeTierLevelGInput) : EmptyResult
        setupClusterTieringG(input: ClusterTieringSetupInput): EmptyResult
        setupClusterTieringG2(input: ClusterTieringSetupInput): Cluster
        applyByolLicense(input: applyByolLicenseInput) : EmptyResult
    }
    type Subscription{
        licenseInfo(accountId: ID): LicenseInfo
        clusterInfo(accountId:ID!, agentId:ID!, workspaceId: ID!, resourceType:RESOURCE_TYPE) : [Cluster]
    }
    `;

module.exports = typeDefs;
