const Joi = require('@hapi/joi');
const {
    AGENT_PENDING_STATUS, AGENT_ACTIVE_STATUS, AGENT_INACTIVE_STATUS, AGENT_UNKNOWN_STATUS
} = require('../utils/consts');

const serviceStatus = Joi.object().keys({
    version: Joi.string().required(),
    status: Joi.string().valid(AGENT_ACTIVE_STATUS, AGENT_INACTIVE_STATUS),
    reason: Joi.string().allow(null)
});

const clientInfraStatusSchema = Joi.object().keys({
    cloudmanager_tiering: serviceStatus
}).allow(null);

const agentSchema = Joi.object().keys({
    useDockerInfra: Joi.boolean(),
    agentId: Joi.string().required(),
    name: Joi.string(),
    provider: Joi.string().required(),
    region: Joi.string().required().allow(''),
    network: Joi.string().required().allow(''),
    subnet: Joi.string().required().allow(''),
    systemId: Joi.string().allow(''),
    status: Joi.string().valid(AGENT_PENDING_STATUS, AGENT_ACTIVE_STATUS, AGENT_INACTIVE_STATUS, AGENT_UNKNOWN_STATUS),
    clientInfraStatus: clientInfraStatusSchema
});

const getAgentsSchema = Joi.object().keys({
    agents: Joi.array().items(agentSchema)
});

const innerAgentSchema = Joi.object().keys({
    clientInfraStatus: clientInfraStatusSchema,
    agent: agentSchema
});

const getAgentsInternalSchema = Joi.object().keys({
    agents: Joi.array().items(innerAgentSchema)
});

const getAgentSchema = Joi.object().keys({
    agent: agentSchema
});

module.exports = {
    getAgentsSchema, agentSchema, getAgentSchema, clientInfraStatusSchema, getAgentsInternalSchema
};
