const Joi = require('@hapi/joi');

const accountSchema = Joi.object().keys({
    accountName: Joi.string().required(),
    accountPublicId: Joi.string().required(),
    isGov: Joi.boolean()
});

const workspaceSchema = Joi.object().keys({
    workspaceName: Joi.string().required(),
    workspacePublicId: Joi.string().required()
});

const resourceSchema = Joi.object().keys({
    resourceIdentifier: Joi.string().required(),
    agentId: Joi.string().required().allow(''),
    workspaceIds: Joi.array().items(Joi.string()),
    resourceClass: Joi.string()
});

const resourcesSchema = Joi.array().items(resourceSchema);

const createAccountResponseSchema = Joi.object().keys({
    accountPublicId: Joi.string().required()
});

const getAccountsSchema = Joi.array().items(accountSchema);

const getWorkspaceSchema = Joi.array().items(workspaceSchema);

const tenancyGetAccountUsersResponseSchema = Joi.array().items(Joi.object().keys({
    name: Joi.string().required(),
    email: Joi.string().email({ tlds: {} }).required(),
    company: Joi.string().required()
})).unique().required();

module.exports = {
    tenancyGetAccountUsersResponseSchema,
    getAccountsSchema,
    getWorkspaceSchema,
    createAccountResponseSchema,
    workspaceSchema,
    resourcesSchema
};
