const Joi = require('@hapi/joi');
const {
    CLOUD_PROVIDERS, FAILED_SUBSCRIPTION, SUBSCRIBED, UNSUBSCRIBE_PENDING, UNSUBSCRIBED, SUSPEND_SUBSCRIPTION, PENDING_SUBSCRIPTION
} = require('../utils/consts');

const subscriptionSchema = Joi.object().keys({
    subscriptionId: Joi.string(),
    cloudProvider: Joi.string().lowercase().valid(...Object.values(CLOUD_PROVIDERS)),
    name: Joi.string(),
    subscriptionStatus: Joi.string().valid(FAILED_SUBSCRIPTION, SUBSCRIBED, UNSUBSCRIBED, UNSUBSCRIBE_PENDING, PENDING_SUBSCRIPTION, SUSPEND_SUBSCRIPTION),
    serviceName: Joi.string(),
    createdAt: Joi.number(),
    accounts: Joi.array().items(Joi.string()),
    contract: Joi.boolean()
});

const listSubscriptionResponse = Joi.array().items(subscriptionSchema);

const listSubscriptionByServiceNameResponse = Joi.object().keys({
    items: listSubscriptionResponse,
    continuationToken: Joi.string()
});

const subscriptionNotificationSchema = Joi.object().keys({
    notificationType: Joi.string().valid('remove-subscription', 'status-change', 'add-subscription').required(),
    subscriptionId: Joi.string().required(),
    accounts: Joi.array().items(Joi.string()),
    subscriptionStatus: Joi.string().valid(FAILED_SUBSCRIPTION, SUBSCRIBED, UNSUBSCRIBED, UNSUBSCRIBE_PENDING, PENDING_SUBSCRIPTION, SUSPEND_SUBSCRIPTION).required(),
    serviceName: Joi.string().required(),
    cloudProvider: Joi.string().lowercase().valid(...Object.values(CLOUD_PROVIDERS)).required(),
    contract: Joi.boolean()
});

module.exports = {
    listSubscriptionResponse, subscriptionSchema, subscriptionNotificationSchema, listSubscriptionByServiceNameResponse
};
