const {
    AGENT_GET_AWS_STORAGE_CLASS, STANDARD_AWS,
    AGENT_LIST_AWS_REGIONS,
    AGENT_LIST_AWS_BUCKETS, AWS, STORAGE_CLASSES_NEW_AGENT
} = require('../../utils/consts');
const {
    regionsResponse, awsBucket, awsBucketsResponse, createBucketRequestSchema, setAwsStorageClassRequestSchema
} = require('../../joi-schemas/agent-schemas');
const getLogger = require('../../utils/logger/logger');
const { gotInstanceForAgent } = require('../../utils/got-utils');
const { validateResponse, validateRequest } = require('../../utils/schema-validation');
const { createAgentPath, createHeadersForAgent } = require('../../utils/utils');

const logger = getLogger();

async function getAwsRegions(agentId) {
    logger.info('get AWS regions', agentId);
    const data = await gotInstanceForAgent.get(createAgentPath(AGENT_LIST_AWS_REGIONS), createHeadersForAgent(agentId));
    validateResponse(data, regionsResponse);
    return data;
}

async function getAwsBuckets(agentId) {
    logger.info('Get AWS buckets', { agentId });
    const data = await gotInstanceForAgent.get(createAgentPath(AGENT_LIST_AWS_BUCKETS), createHeadersForAgent(agentId));
    validateResponse(data, awsBucketsResponse);
    return data;
}

async function createAwsBucket(agentId, name, region) {
    try {
        logger.info('Create AWS bucket', {
            agentId, name, region
        });
        const requestData = { name, region };
        validateRequest(requestData, createBucketRequestSchema);
        const data = await gotInstanceForAgent.post(createAgentPath(AGENT_LIST_AWS_BUCKETS), { json: requestData, ...createHeadersForAgent(agentId) });
        validateResponse(data, awsBucket);
        return data;
    } catch (err) {
        logger.error('Failed to create bucket on AWS', err);
        throw err;
    }
}

async function setAwsTierLevel(agentId, bucket, tierLevel) {
    logger.info('change tier level', {
        agentId, bucket, tierLevel
    });
    const storageClass = STORAGE_CLASSES_NEW_AGENT[AWS][tierLevel];
    const requestData = { bucket, storageClass };
    if (storageClass !== STANDARD_AWS) {
        validateRequest(requestData, setAwsStorageClassRequestSchema);
        return gotInstanceForAgent.put(createAgentPath(AGENT_GET_AWS_STORAGE_CLASS), { json: requestData, ...createHeadersForAgent(agentId) });
    }
}

async function getAwsTierLevel(agentId, bucket, accountId) {
    logger.info('get tier level', { agentId, bucket, accountId });
    return gotInstanceForAgent.get(`${createAgentPath(AGENT_GET_AWS_STORAGE_CLASS, accountId)}?bucket=${bucket}`, createHeadersForAgent(agentId));
}

module.exports = {
    getAwsRegions, getAwsBuckets, createAwsBucket, setAwsTierLevel, getAwsTierLevel
};
