const ms = require('ms');
const getLogger = require('../utils/logger/logger');
const {
    JWR_TOKEN_TENANCY_AUDIENCE, CLIENT_ID, CLIENT_SECRET, JWT_TOKEN_AUTH0
} = require('../utils/consts');
const { gotInstanceForOuterServices } = require('../utils/got-utils');

const logger = getLogger();

let SERVICE_TOKEN_CACHE; // audience to token

async function jwtGetUserInfo(jwtToken) {
    const userInfo = await gotInstanceForOuterServices.get(`${JWT_TOKEN_AUTH0}/userinfo`, {
        headers: {
            authorization: jwtToken
        }
    });
    return userInfo['http://cloud.netapp.com/user_metadata'];
}

async function createServiceTokenRequest() {
    const data = await gotInstanceForOuterServices.post(`${JWT_TOKEN_AUTH0}/oauth/token`, {
        json: {
            audience: JWR_TOKEN_TENANCY_AUDIENCE,
            client_id: CLIENT_ID,
            client_secret: CLIENT_SECRET,
            grant_type: 'client_credentials'
        }
    });
    return { token: `${data.token_type} ${data.access_token}`, expiresIn: data.expires_in };
}

async function createServiceToken() {
    try {
        logger.info('Creating service token ');
        const { token, expiresIn } = await createServiceTokenRequest();
        SERVICE_TOKEN_CACHE = token;
        const shouldBeActivatedIn = ms(`${expiresIn}s`) < ms('1m') ? ms(`${expiresIn}s`) - ms('1m') : ms(`${expiresIn}s`) - ms('30m');
        logger.info(`Service token received, setTimeout with ${shouldBeActivatedIn} `);
        setTimeout(() => createServiceToken(), shouldBeActivatedIn);
    } catch (err) {
        logger.error('Failed to receive service token ', err);
        setTimeout(() => createServiceToken(), ms('1m'));
    }
}

function getServiceToken() {
    return SERVICE_TOKEN_CACHE;
}

module.exports = {
    createServiceToken, getServiceToken, jwtGetUserInfo
};
