const AWS = require('aws-sdk');
const { DEFAULT_AWS_REGION } = require('../../utils/consts');
const HttpError = require('../../utils/errors');
const getLogger = require('../../utils/logger/logger');

const logger = getLogger();

async function getCallerIdentity(accessKeyId, secretAccessKey) {
    const sts = new AWS.STS({ accessKeyId, secretAccessKey, region: DEFAULT_AWS_REGION });
    try {
        await sts.getCallerIdentity({}).promise();
    } catch (err) {
        logger.warn('Caller identity is not available', err);
        throw new HttpError('The credentials that you entered are invalid. Reenter your credentials and try again', 403);
    }
}

module.exports = getCallerIdentity;
