const mongoose = require('mongoose');

const subscriptionsSchema = new mongoose.Schema({
    topic: { type: String, required: false },
    accountId: { type: String, required: true },
    subscriptionId: { type: String, required: true }
}, {
    timestamps: true, // assign createdAt and updatedAt
    toJSON: {
        transform(doc, ret) {
            const toReturn = ret;
            delete toReturn.__v;
            return toReturn;
        }
    }
});

subscriptionsSchema.index({
    subscriptionId: 1
}, { expireAfterSeconds: 3600 });

const Subscription = mongoose.model('Subscription', subscriptionsSchema);

async function findAccountsWithSubscriptions(topic) {
    return Subscription.aggregate([
        { $match: { topic } },
        {
            $lookup: {
                from: 'accounts',
                localField: 'accountId',
                foreignField: 'accountId',
                as: 'accountData'
            }
        },
        { $unwind: '$accountData' },
        { $group: { _id: { accountId: '$accountId', account: '$accountData' } } },
        { $project: { account: '$_id.account', _id: 0 } }
    ]);
}

module.exports = { Subscription, findAccountsWithSubscriptions };
