const { groupBy } = require('lodash');
const { getAgentsInternal } = require('../lib/cloud-manager/agents');
const { AGENT_ACTIVE_STATUS } = require('../utils/consts');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

async function findAgentDetailsForResources(resources, agents, accountId) {
    logger.info('Finding agent details for resources:', JSON.stringify({ resources, agents, accountId }));
    const agentsByAgentId = groupBy(agents, 'agentId');
    const resourcesByAgents = groupBy(resources, 'agentId');
    // resourcesByAgents looks like {agentId:[{resource}, {resource}]
    const resourcesWithAgentsDetails = Object.keys(resourcesByAgents).map(agentId => {
        if (agentsByAgentId[agentId]) {
            const [agent] = agentsByAgentId[agentId];
            const {
                status: agentStatus, provider: agentCloudProvider, useDockerInfra, systemId: agentSystemId
            } = agent;
            const agentDetails = {
                agentId,
                agentStatus,
                agentCloudProvider,
                agentSystemId,
                useDockerInfra
            };
            return resourcesByAgents[agentId].map(resourceObj => Object.assign(resourceObj, agentDetails));
        }
        return undefined;
    });
    return resourcesWithAgentsDetails.flat().filter(resource => resource);
}

function findValidAgents(agents) {
    return agents.filter(agent => agent.useDockerInfra);
}

function isTieringContainerHealthy(agent) {
    const tieringContainerInfo = agent?.clientInfraStatus?.cloudmanager_tiering;
    return agent.useDockerInfra && tieringContainerInfo && tieringContainerInfo.status === AGENT_ACTIVE_STATUS;
}

async function getActiveAgentsInternal() {
    const { agents } = await getAgentsInternal();
    return agents.filter(agent => agent.status === AGENT_ACTIVE_STATUS && isTieringContainerHealthy(agent));
}

module.exports = {
    findAgentDetailsForResources, findValidAgents, getActiveAgentsInternal, isTieringContainerHealthy
};
