const Promise = require('bluebird');
const { ApolloError } = require('apollo-server');
const jwtVerify = require('../utils/jwt');
const { JWR_TOKEN_TENANCY_AUDIENCE, JWT_TOKEN_CLOUD_MANAGER_AUDIENCE } = require('../utils/consts');
const { setUserPortalId, setUserName } = require('../utils/async-local-storage');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

async function authenticate(token, request) {
    if (!token) {
        logger.info(`UNAUTHORIZED additional information: user-agent: ${request.headers['user-agent']}, remote-address: ${request.socket.remoteAddress}`);
        throw new ApolloError('UNAUTHORIZED', 401);
    }
    try {
        const payload = await Promise.any([
            jwtVerify(token, JWR_TOKEN_TENANCY_AUDIENCE),
            jwtVerify(token, JWT_TOKEN_CLOUD_MANAGER_AUDIENCE)
        ]);
        setUserPortalId(payload.sub);
        setUserName(payload['http://cloud.netapp.com/full_name']);
    } catch (err) {
        err.forEach(e => logger.info('Failed to authenticate', e));
        logger.info(`Failed to authenticate token. Additional information: user-agent: ${request.headers['user-agent']}, remote-address: ${request.socket.remoteAddress}`, token);
        throw new ApolloError('UNAUTHORIZED', 401);
    }
}

module.exports = authenticate;
