const moment = require('moment');
const hyperid = require('hyperid');
const {
    getS3, putObject, getObject, deleteObject
} = require('../lib/aws/s3');
const { HUBSPOT_FIELDS } = require('../utils/consts');
const { updateHubspotContactByUserToken } = require('../lib/hubspot');
const { putSgwsObject, getSgwsObject, deleteSgwsObject } = require('../lib/agent/sgws');
const getLogger = require('../utils/logger/logger');

const logger = getLogger();

async function verifyPermission(cloudProvider, region, bucket, keys) {
    try {
        await updateHubspotContactByUserToken(HUBSPOT_FIELDS.permission_check, moment().utc().startOf('day').valueOf());
        logger.info('verify permissions', {
            cloudProvider, region, bucket, keys
        });
        const { accessKey, secretKey } = keys;
        const key = `cloudTiering_test_${hyperid().uuid}`;
        const s3 = getS3(cloudProvider, region, accessKey, secretKey);
        // Put Object
        await putObject(s3, bucket, key);
        // getObject
        await getObject(s3, bucket, key);
        // deleteObject
        await deleteObject(s3, bucket, key);
    } catch (err) {
        await updateHubspotContactByUserToken(HUBSPOT_FIELDS.failed, HUBSPOT_FIELDS.permission_check);
        throw err;
    }
}

async function verifySgwsPermission(agentId, clusterId, bucket, keys, host, port) {
    try {
        logger.info('Verify sgws permissions', {
            agentId, clusterId, bucket, keys, host, port
        });
        await updateHubspotContactByUserToken(HUBSPOT_FIELDS.permission_check, moment().utc().startOf('day').valueOf());
        logger.info('verify permissions', {
            clusterId, host, port, bucket, keys
        });
        const { accessKey, secretKey } = keys;
        const key = `cloudTiering_test_${hyperid().uuid}`;

        // Put Object
        await putSgwsObject(agentId, bucket, key, '', accessKey, secretKey, host, port);
        // getObject
        await getSgwsObject(agentId, bucket, key, accessKey, secretKey, host, port);
        // deleteObject
        await deleteSgwsObject(agentId, bucket, key, accessKey, secretKey, host, port);
    } catch (err) {
        await updateHubspotContactByUserToken(HUBSPOT_FIELDS.failed, HUBSPOT_FIELDS.permission_check);
        throw err;
    }
}

module.exports = { verifyPermission, verifySgwsPermission };
