const { createHook } = require('async_hooks');

const contexts = new Map();
const stack = [];
let currentContext = {};

function set(name, value) {
    currentContext[name] = value;
}

function get(name) {
    return currentContext[name];
}

function create() {
    const asyncHook = createHook({
        init: asyncId => contexts.set(asyncId, currentContext),
        before: asyncId => {
            const context = contexts.get(asyncId);

            if (context) {
                stack.push(currentContext);
                currentContext = context;
            }
        },
        after: asyncId => {
            const context = contexts.get(asyncId);

            if (context) {
                currentContext = stack.pop();
            }
        },

        destroy: asyncId => contexts.delete(asyncId),
        promiseResolve: asyncId => contexts.delete(asyncId)

    });

    asyncHook.enable();

    return {
        set: (name, value) => set(name, value),
        get: name => get(name)
    };
}

module.exports = create;
