const getLogger = require('./logger/logger');
const { auditRecordGroupSchema } = require('../joi-schemas/audit-schemas');

const logger = getLogger();

function validateSchema(data, schema, allowUnknown = false) {
    const result = schema.validate(data, { allowUnknown });
    if (result.error) {
        logger.error('Schema Validation error', result.error);
        throw result.error;
    }
}

function validateAuditGroup(auditGroup) {
    // if resource & agent name exists, we must have also resource & agent id.
    if ((auditGroup.resourceName && !auditGroup.resourceId) || (!auditGroup.resourceName && auditGroup.resourceId)) {
        throw new Error('If resource name exists, resource id is also required, vice versa');
    }
    if ((auditGroup.agentName && !auditGroup.agentId) || (!auditGroup.agentName && auditGroup.agentId)) {
        throw new Error('If agent name exists, agent id is also required, vice versa');
    }
    validateSchema(auditGroup, auditRecordGroupSchema);
}

function validateResponse(data, schema) {
    validateSchema(data, schema, true);
}

function validateRequest(data, schema) {
    validateSchema(data, schema, false);
}

module.exports = {
    validateRequest, validateResponse, validateSchema, validateAuditGroup
};
