const { validateResponse } = require('../../../src/utils/schema-validation');
const { getAccountsSchema, createAccountResponseSchema, workspaceSchema } = require('../../../src/joi-schemas/multi-tenancy-schemas');

const getAccountsValidResponse = [{
    userRole: 'admin',
    accountName: 'accountName',
    accountPublicId: '456789'
}];

const account = {
    userRole: 'admin',
    accountName: 'accountName',
    accountPublicId: '456789'
};

const workspace = { workspacePublicId: '123456', workspaceName: 'workspaceName' };

const getAccountsInValid = account;

validateResponse(getAccountsValidResponse, getAccountsSchema);

describe('validate multi-tenancy response', () => {
    test('successfully validate get accounts response', () => {
        expect(validateResponse(getAccountsValidResponse, getAccountsSchema)).not.toBeDefined();
    });

    test('failed to validate get accounts with non-array response', () => {
        function validateInvalidResponse() {
            return validateResponse(getAccountsInValid, getAccountsSchema);
        }
        expect(validateInvalidResponse).toThrow('must be an array');
    });

    test('successfully validate create account response', () => {
        expect(validateResponse(account, createAccountResponseSchema)).not.toBeDefined();
    });

    test('successfully validate create workspace response', () => {
        expect(validateResponse(workspace, workspaceSchema)).not.toBeDefined();
    });
});
