const { supportedVolumeSettings } = require('../../src/operations/tiering-policy-operations');
const {
    ALL, SNAPSHOT_ONLY, AUTO, BACKUP, NONE
} = require('../../src/utils/consts');

describe('supportedTieringPolicies', () => {
    test('ontap version 9.2 and not DP volume should return [snapshot_only]', () => {
        expect(supportedVolumeSettings(9.2, false).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY]);
    });
    test('ontap version 9.3 and not DP volume should return [snapshot_only]', () => {
        expect(supportedVolumeSettings(9.3, false).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY]);
    });
    test('ontap version 9.4 and not DP volume should return [snapshot_only, auto, none]', () => {
        expect(supportedVolumeSettings(9.4, false).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY, AUTO]);
    });
    test('ontap version 9.2 and DP volume should return [backup, none]', () => {
        expect(supportedVolumeSettings(9.2, true).map(setting => setting.tieringPolicy)).toEqual([NONE, BACKUP, SNAPSHOT_ONLY]);
    });
    test('ontap version 9.4 and DP volume should return [backup, none, snapshot_only, auto]', () => {
        expect(supportedVolumeSettings(9.4, true).map(setting => setting.tieringPolicy)).toEqual([NONE, BACKUP, SNAPSHOT_ONLY, AUTO]);
    });
    test('ontap version 9.6 and DP volume should return [snapshot_only, all, auto, none]', () => {
        expect(supportedVolumeSettings(9.6, false).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY, AUTO, ALL]);
    });
    test('ontap version 9.6 and DP volume and tiered should return [snapshot_only, all, auto, none]', () => {
        expect(supportedVolumeSettings(9.6, false, true).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY, AUTO, ALL]);
    });
    test('ontap version 9.6 and  DP volume should return [all, none, snapshot_only, auto]', () => {
        expect(supportedVolumeSettings(9.6, true).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY, AUTO, ALL]);
    });
    test('ontap version 9.2 and not DP and tiered volume should return [none, snapshot_only]', () => {
        expect(supportedVolumeSettings(9.2, false).map(setting => setting.tieringPolicy)).toEqual([NONE, SNAPSHOT_ONLY]);
    });
});
