const got = require('got');
const hyperid = require('hyperid');
const {
    AGENT_DESCRIBE_SVM_VOLUMES_PATH,
    AGENT_LICENSES_PATH,
    AGENT_DESCRIBE_OBJECT_STORES_PATH,
    AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH,
    AGENT_DESCRIBE_AGGREGATES_PATH, ON_STATUS, AGENT_ZAPI_PATH, AGENT_ENABLE_COLD_DATA_REPORTING_PATH,
    CLOUD_MANAGER_CLUSTERS_PATH_PREFIX, CLOUD_MANAGER_API_PREFIX, CLOUD_MANAGER_ENDPOINT,
    AGENT_ENDPOINT, AGENT_API_PREFIX, AGENT_API_PROVIDERS_PREFIX
} = require('../../../src/utils/consts');
const { signJwtToken } = require('../simulator-utils');
const { reset } = require('../simulator-state');
const { createClusterRequest, createAggregate } = require('../../testUtils');
require('../scopes/agent-zapi-scope');
require('../scopes/agents-scope');
require('../scopes/clusters-scope');

describe('agent-zapi-scope', () => {
    describe('aggregates-operations', () => {
        beforeEach(() => reset());

        test('create/get single aggregate', async () => {
            // create cluster
            const cluster = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            const aggregate = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregate,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            const data = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            expect(data).toEqual([aggregate]);
        });

        test('create/get single aggregate with different users', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            const cluster2 = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            const aggregatesUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken('user2')
                }
            });

            const aggregateCluster2 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken('user2')
                }
            });

            const aggregatesUser2 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken('user2')
                }
            });

            expect(aggregatesUser1).toEqual([aggregateCluster1]);
            expect(aggregatesUser2).toEqual([aggregateCluster2]);
        });

        test('create/get multiple aggregates', async () => {
            const cluster = createClusterRequest(hyperid().uuid, ON_STATUS);
            const aggregate = createAggregate('aggr1');
            const aggregate2 = createAggregate('aggr2');

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregate,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregate2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            const data = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            expect(data).toEqual([aggregate, aggregate2]);
        });

        test('create/get multiple aggregates with different users', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            const cluster2 = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken('user2')
                }
            });

            // create aggregates
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            // create aggregates
            const aggregateCluster2 = createAggregate('aggr2');
            const aggregate2Cluster2 = createAggregate('aggr3');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken('user2')
                }
            });
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregate2Cluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken('user2')
                }
            });

            const aggregatesUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            const aggregatesUser2 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken('user2')
                }
            });

            expect(aggregatesUser1).toEqual([aggregateCluster1]);
            expect(aggregatesUser2).toEqual([aggregateCluster2, aggregate2Cluster2]);
        });
        test('attach object store - check only = true', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            // attach objectstore

            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECT_STORES_PATH}`, {
                json: {
                    aggregateName: 'aggr1',
                    objectStoreName: 'test',
                    checkOnly: true,
                    allowFlexgroup: true
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            const aggregatesUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            expect(aggregatesUser1).toEqual([aggregateCluster1]);
        });

        test('attach object store to an aggregate of different user- should fail', async () => {
            try {
                // create cluster
                const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);

                await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                    json: cluster1,
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        authorization: signJwtToken()
                    }
                });
                // create aggregate
                const aggregateCluster1 = createAggregate('aggr1');
                // create object-store config
                await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                    json: aggregateCluster1,
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        'X-Agent-Id': 'agentId',
                        authorization: signJwtToken()
                    }
                });

                // attach object store
                await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECT_STORES_PATH}`, {
                    json: {
                        aggregateName: 'aggr1',
                        objectStoreName: 'test',
                        checkOnly: true,
                        allowFlexgroup: true
                    },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        'X-Agent-Id': 'agentId',
                        authorization: signJwtToken('user2')
                    }
                });
            } catch (err) {
                expect(err.response.body.statusCode).toEqual(404);
            }
        });

        test('attach object store - check only = false, check an objectStoreName field exists', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            // create object-store
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                json: {
                    objectStoreName: 'object-store',
                    objectStoreProviderType: 'aws-s3',
                    server: 'server',
                    s3Name: 'bucket',
                    ipSpace: 'ipSpace',
                    keys: { accessKey: '1', secretKey: '1' },
                    checkOnly: false
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            // attach object store
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECT_STORES_PATH}`, {
                json: {
                    aggregateName: 'aggr1',
                    objectStoreName: 'object-store',
                    checkOnly: false,
                    allowFlexgroup: true
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            const aggregatesUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            const objectStoresUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECT_STORES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            expect(objectStoresUser1[0].name).toEqual('object-store');
            // after attach object store to an aggregate - isObjectStoreAttachEligible becomes false
            expect(aggregatesUser1[0].isObjectStoreAttachEligible).toEqual(false);
        });
    });

    describe('clusters operations', () => {
        beforeEach(() => reset());
        test('create aws object store config -  existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // create object store config
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                json: {
                    objectStoreName: 'object-store',
                    objectStoreProviderType: 'aws-s3',
                    server: 'server',
                    s3Name: 'bucket',
                    ipSpace: 'ipSpace',
                    keys: { accessKey: '1', secretKey: '1' },
                    checkOnly: false
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // get object stores config
            const objectStoresConfigUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            expect(objectStoresConfigUser1[0].objectStoreName).toEqual('object-store');
        });
        test('create gcp object store config -  existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // create object store config
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                json: {
                    objectStoreName: 'object-store',
                    objectStoreProviderType: 'googlecloud',
                    server: 'server',
                    s3Name: 'bucket',
                    ipSpace: 'ipSpace',
                    keys: { accessKey: '1', secretKey: '1' },
                    checkOnly: false
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // get object stores config
            const objectStoresConfigUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            expect(objectStoresConfigUser1[0].objectStoreName).toEqual('object-store');
        });
        test('create sgws object store config -  existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // create object store config
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                json: {
                    objectStoreName: 'object-store',
                    objectStoreProviderType: 'sgws',
                    server: 'server',
                    s3Name: 'bucket',
                    ipSpace: 'ipSpace',
                    port: 80,
                    keys: { accessKey: '1', secretKey: '1' },
                    checkOnly: false
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // get object stores config
            const objectStoresConfigUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            expect(objectStoresConfigUser1[0].objectStoreName).toEqual('object-store');
        });
        test('create azure object store config -  existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // create object store config
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                json: {
                    objectStoreName: 'object-store',
                    objectStoreProviderType: 'aws-s3',
                    server: 'server',
                    s3Name: 'bucket',
                    ipSpace: 'ipSpace',
                    keys: { accessKey: '1', secretKey: '1' },
                    checkOnly: false
                },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            // get object stores config
            const objectStoresConfigUser1 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });
            expect(objectStoresConfigUser1[0].objectStoreName).toEqual('object-store');
        });

        test('create aws object store config - non existing cluster', async () => {
            try {
                // create cluster - for user scenario
                const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
                await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                    json: cluster1,
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        authorization: signJwtToken()
                    }
                });

                await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}cluster5${AGENT_DESCRIBE_OBJECTSTORE_CONFIG_PATH}`, {
                    json: {
                        objectStoreName: 'object-store',
                        objectStoreProviderType: 'aws-s3',
                        server: 'server',
                        s3Name: 'bucket',
                        ipSpace: 'ipSpace',
                        keys: { accessKey: '1', secretKey: '1' },
                        checkOnly: false
                    },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        'X-Agent-Id': 'agentId',
                        authorization: signJwtToken()
                    }
                });
            } catch (err) {
                expect(err.response.body).toBe('Cluster for fabric pool not found');
            }
        });

        test('enableColdDataReporting-   existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create aggregate
            const aggregateCluster1 = createAggregate('aggr1');
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                json: aggregateCluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}/aggr1${AGENT_ENABLE_COLD_DATA_REPORTING_PATH}`, {
                json: { enable: false },
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            // verify - describe aggregate
            const aggregates = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_AGGREGATES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    'X-Agent-Id': 'agentId',
                    authorization: signJwtToken()
                }
            });

            expect(aggregates[0].isInactiveDataReportingEnabled).toEqual(false);
        });

        test('enableColdDataReporting- non existing cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            try {
                await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}test2${AGENT_DESCRIBE_AGGREGATES_PATH}/aggr1${AGENT_ENABLE_COLD_DATA_REPORTING_PATH}`, {
                    json: { enable: true },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        'X-Agent-Id': 'agentId',
                        authorization: signJwtToken()
                    }
                });
            } catch (err) {
                expect(err.response.body).toBe('cluster was not found');
            }
        });

        test('apply-license and get-license on cluster', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_LICENSES_PATH}`,
                {
                    json: {
                        statusResp: {
                            serialNumber: '123456',
                            version: '1',
                            product: 'fabricPool',
                            licenses: {
                                capacity: '10',
                                type: 'capacity',
                                package: 'fabricPool'
                            }
                        },
                        trackingId: '123',
                        Signature: 'signature'
                    },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: { authorization: signJwtToken() }
                });

            const licenses = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_LICENSES_PATH}`,
                {
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: { authorization: signJwtToken() }
                });
            expect(licenses).toMatchObject([{
                currentCapacity: 0,
                maxCapacity: 10240,
                serialNumber: '123456',
                package: 'fabricpool'
            }]);
        });
    });

    describe('volumes operations', () => {
        test('create volume', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create volume
            const volume = {
                name: 'volumeName',
                svmName: 'svm_1',
                aggregateName: 'aggr-1',
                usedSize: 5497558138880,
                sizeTotal: 10995116277760,
                tieringPolicy: 'snapshot_only',
                volumeType: 'rw'
            };
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: volume,
                headers: {
                    authorization: signJwtToken()
                }
            });
            // get volumes
            const volumes = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}/svm_1${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            expect(volumes[0]).toMatchObject(volume);
        });

        test('get volumes when there are no volumes', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // get volumes
            const volumes = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_SVM_VOLUMES_PATH}?svmName=svm_1`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            expect(volumes).toMatchObject([]);
        });

        test('create/get volumes of different users- each user should receive its own volumes', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            // create volume
            const volume = {
                name: 'volumeName',
                svmName: 'svm_1',
                aggregateName: 'aggr-1',
                usedSize: 5497558138880,
                sizeTotal: 10995116277760,
                tieringPolicy: 'snapshot_only',
                volumeType: 'rw'
            };
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: volume,
                headers: {
                    authorization: signJwtToken()
                }
            });

            const volumes = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}/svm_1${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            const cluster2 = createClusterRequest(hyperid().uuid, ON_STATUS);

            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster2,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken('user2')
                }
            });
            const volume2 = {
                name: 'volume2',
                svmName: 'svm_1',
                aggregateName: 'aggr-1',
                usedSize: 5497558138880,
                sizeTotal: 10995116277760,
                tieringPolicy: 'snapshot_only',
                volumeType: 'rw'
            };

            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: volume2,
                headers: {
                    authorization: signJwtToken('user2')
                }
            });
            const volumes2 = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster2.publicId}/svm_1${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken('user2')
                }
            });

            expect(volumes).toMatchObject([volume]);
            expect(volumes2).toMatchObject([volume2]);
        });

        test('modify volumes - modify for non existing volume', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            try {
                await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}/a${AGENT_DESCRIBE_SVM_VOLUMES_PATH}/b`, {
                    json: {
                        tieringPolicy: 'auto'
                    },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        authorization: signJwtToken()
                    }
                });
            } catch (err) {
                expect(err.response.statusCode).toBe(404);
            }
        });

        test('modify volumes - modify for existing volume', async () => {
            // create cluster
            const cluster1 = createClusterRequest(hyperid().uuid, ON_STATUS);
            await got.post(`${CLOUD_MANAGER_ENDPOINT}${CLOUD_MANAGER_API_PREFIX}${CLOUD_MANAGER_CLUSTERS_PATH_PREFIX}`, {
                json: cluster1,
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });

            // create volume
            const volume = {
                name: 'volumeName',
                svmName: 'svm_1',
                aggregateName: 'aggr-1',
                usedSize: 5497558138880,
                sizeTotal: 10995116277760,
                tieringPolicy: 'snapshot_only',
                volumeType: 'rw'
            };
            await got.post(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                json: volume,
                headers: {
                    authorization: signJwtToken()
                }
            });
            // change tiering policy
            await got.put(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}/svm_1${AGENT_DESCRIBE_SVM_VOLUMES_PATH}/volumeName`,
                {
                    json: {
                        tieringPolicy: 'auto'
                    },
                    resolveBodyOnly: true,
                    responseType: 'json',
                    headers: {
                        authorization: signJwtToken()
                    }
                });
            // get volumes
            const volumes = await got.get(`${AGENT_ENDPOINT}${AGENT_API_PREFIX}account1${AGENT_API_PROVIDERS_PREFIX}${AGENT_ZAPI_PATH}${cluster1.publicId}/svm_1${AGENT_DESCRIBE_SVM_VOLUMES_PATH}`, {
                resolveBodyOnly: true,
                responseType: 'json',
                headers: {
                    authorization: signJwtToken()
                }
            });
            expect(volumes[0].tieringPolicy).toEqual('auto');
        });
    });
});
