import React, {Component} from 'react';
import classNames from "classnames";
import ScrollArea from 'react-scrollbar';
import _ from 'lodash'

export class DialogContainer extends Component{
    constructor(props, context){
        super(props, context);
        this.state = {modalClasses: []};
        this.closeDialogHandler = (e) => {
            if(e.keyCode === 8 && e.target.nodeName !== "INPUT" && e.target.nodeName !== "TEXTAREA"){
                e.preventDefault();
            }

            if (e.keyCode === 27) {
                this.closeDialog();
            }
        }
    }

    componentDidMount(){
        dialogContainer = this;
    }

    setDialog(dialog, parent, disableClose) {
        if(this.state.dialog === dialog) {
            return;
        }

        this.setState({dialog: dialog, style: (parent ? {opacity: 0} : {}), disableClose});
        if (!disableClose) {
            document.addEventListener('keydown', this.closeDialogHandler);
        }

        if(parent) {
            const parentBr = parent.getBoundingClientRect();
            setTimeout(() => {

                const modalBr = this._modal.getBoundingClientRect();

                const x = (parentBr.left + parentBr.width/2) - modalBr.left;
                const y = (parentBr.top + parentBr.height/2) - (modalBr.top + modalBr.height);
                this.setState(Object.assign({}, this.state, {style: {opacity: 0, transform: `translate(${x}px, ${y}px) scale(0)`}}));

                setTimeout(() => {
                    this.setState(Object.assign({}, this.state, {style: {transition: "transform 0.5s cubic-bezier(0.25, 0.8, 0.25, 1)", transformOrigin: "0 100%", opacity: 1, transform: "translate(0, 0) scale(1)"}}))
                }, 100)
            });
        }
    }

    closeDialog(){
        this.setState({dialog: null, modalClasses: []});

        document.removeEventListener('keydown', this.closeDialogHandler);
    }

    addClassToModal(className) {
        if (!this.state.modalClasses.includes(className)) {
            this.setState({modalClasses: this.state.modalClasses.concat(className)});
        }
    }

    render(){
        const content = this.state.dialog ?
            React.cloneElement(this.state.dialog, {closeDialog: this.closeDialog.bind(this), addClassToModal: this.addClassToModal.bind(this)}) : null;
        return (
            content ? (
                    <div className={classNames("dialog", content.props.className)}>
                        <div className="mask" onClick={this.state.disableClose ? _.noop : this.closeDialog.bind(this)}></div>
                        <div className={classNames("modal", this.state.modalClasses)} ref={(el) => this._modal = el} style={this.state.style}>
                            {content}
                        </div>
                    </div>) : <div></div>

        )
    }
}

let dialogContainer;

export const openDialog = (dialog, parent, disableClose) => {
    dialogContainer.setDialog(dialog, parent, disableClose);
};

export const DialogTextAreaScroll = ({children}) => (
    <ScrollArea
        style={{height: "251px" }}
        className="textarea"
        contentClassName="content"
        verticalScrollbarStyle={{borderRadius: 0, backgroundColor: "#818483", width: "5px", position: "relative"}}
        verticalContainerStyle={{borderRadius: 0, opacity: 1, width: "5px"}}
        horizontal={false}
        smoothScrolling= {true}
        minScrollSize={40}
        >
        {children}
    </ScrollArea>
);
