import React from 'react';
import classNames from 'classnames';


import './enforcementButton.scss'
import {NavLink} from "react-router-dom";
import {useQuery} from "@apollo/client";
import {GET_LAZY_CLUSTERS_QUERY, GET_LICENSE_INFO_QUERY} from "../../graphql/queries";
import {connect} from "react-redux";
import {checkShouldEnforce} from "../../utils/enforcmentUtil";


const EnforcementButton = ({accountId, workspaceId, agentId}) => {
    const {data: licenseData} = useQuery(GET_LICENSE_INFO_QUERY, {
        fetchPolicy: "cache-only",
        variables: {
            accountId,
        }
    })
    const {data: clustersData} = useQuery(GET_LAZY_CLUSTERS_QUERY, {
        fetchPolicy: "cache-only",
        variables: {
            accountId,
            workspaceId,
            agentId
        }
    })
    if (!licenseData || !clustersData) {
        return null;
    }
    const {licenseInfo: {daysLeftForTrial, subscriptions}} = licenseData;
    const {lazyClusters} = clustersData;

    const isSubscribed = subscriptions.some(({status}) => status === 'subscribed')
    const isSomeClusterEnforced = lazyClusters.some((cluster) => checkShouldEnforce(cluster))

    if (daysLeftForTrial === null || isSubscribed || (daysLeftForTrial < 1 && !isSomeClusterEnforced)) {
        return null;
    }
    const buttonText = daysLeftForTrial > 0 ? `${daysLeftForTrial} days are left on your free trial. Subscribe now` : 'Your free trial ended. Subscribe now';

    return <NavLink to="/license" className={classNames("enforcement-button", {
            'low-severity': daysLeftForTrial > 10,
            'medium-severity': daysLeftForTrial > 5 && daysLeftForTrial < 11,
            'high-severity': daysLeftForTrial < 6
        }
    )}>
        {buttonText}
    </NavLink>
}

const mapStateToProps = state => ({
    accountId: state.general.accountId,
    agentId: state.general.agentId,
    workspaceId: state.general.workspaceId,
});

export default connect(mapStateToProps)(EnforcementButton);