import React, { Fragment } from 'react'
import Isvg from 'react-inlinesvg'
import classNames from 'classnames'
require('./setupWizardDiagram.scss');

export default ({ flowStep, withServiceConnector, withWarning, clusterName, warningReason }) => {
    const showArrowV = flowStep === "setup-complete";
    const getInnerArrowPart = () => {
        if (withServiceConnector) {
            return (
                <Fragment>
                    <Isvg className="diagram-arrow-small" src={require('../../assets/svgs/diagram-arrow.svg')}/>
                    <div className="shape-with-name">
                        <Isvg className="diagram-service-connector" src={require('../../assets/svgs/service-connector-ok.svg')}/>
                        <div>Connector</div>
                    </div>
                    <Isvg className="diagram-arrow-small" src={require('../../assets/svgs/diagram-arrow.svg')}/>
                </Fragment>
            )
        }
        else if (showArrowV) {
            return (<Isvg className="diagram-arrow" src={require('../../assets/svgs/diagram-arrow-v.svg')}/>)
        }
        else if (withWarning){
            return (<Isvg className="diagram-arrow warning" src={require('../../assets/svgs/diargram-arrow-warning.svg')}/>)
        }
        else return (<Isvg className="diagram-arrow" src={require('../../assets/svgs/diagram-arrow.svg')}/>)
    };

    return (
        <div className="right-panel">
            <div className="diagram">
                <div className={classNames("diagram-title", {warning: withWarning})}>{withWarning ? `Data from cluster ${clusterName} can’t be tiered`: "Connectivity"}</div>
                {!withWarning && <div className="diagram-title-info">Cloud Tiering configures the set up between the ONTAP cluster and the bucket/container that the cluster will tier data to.</div>}
                {withWarning && <div className="diagram-title-info">{warningReason}</div>}
                <div className={`shapes-container ${withServiceConnector ? 'wide' : ''}`}>
                    <div className={`shape-with-name move-left ${withWarning ? 'warning' : ''}`}>
                        <Isvg className="diagram-cluster" src={require('../../assets/svgs/diagram-cluster.svg')}/>
                        <div>Cluster</div>
                    </div>
                    {getInnerArrowPart(showArrowV, withServiceConnector, withWarning)}
                    <div className={`shape-with-name move-right ${withWarning ? 'warning' : ''}`}>
                        <Isvg className="diagram-bucket" src={require('../../assets/svgs/diagram-bucket.svg')}/>
                        <div>Bucket/Container</div>
                    </div>
                </div>
            </div>
        </div>
    );
}

