import DefaultDialogLayout from "../../widgets/DefaultDialogLayout";
import React, {useCallback, useState} from "react";
import {Field, reduxForm} from "redux-form";
import {InputField, InputFieldStaticPlaceholder} from "../../forms/forms";
import Validator from "validatorjs";
import {APPLY_BYOLL_LICENSE} from "../../../graphql/queries";
import {useMutation} from "@apollo/client";
import {extractError} from "../../../utils/utils";
import {connect} from "react-redux";

require('./activeByolDialog.scss')

const useHandleAddLicense = (clusterId, agentId, closeDialog, accountId, workspaceId, dispatch) => {

    const [addLicense, {loading}] = useMutation(APPLY_BYOLL_LICENSE)
    const [error, setError] = useState(null)
    const handleAddLicense = useCallback(({licenseSerialNumber, nssPassword, nssUsername}) => {
        return addLicense({
            variables: {
                input: {
                    nssUserName: nssUsername,
                    nssPassword,
                    clusterId,
                    serialNumber: licenseSerialNumber,
                    accountId,
                    agentId,
                    workspaceId
                }
            }
        }).then(() => closeDialog())
            .catch(error => setError(extractError(error)))
    }, [addLicense, clusterId, agentId, closeDialog, accountId, workspaceId])
    return {addLicense: handleAddLicense, loading, error}

}

const ActivateByolDialog = ({closeDialog, clusterInfo, handleSubmit, accountId, workspaceId, dispatch}) => {
    const {clusterId, agentId} = clusterInfo;
    const {addLicense, loading, error} = useHandleAddLicense(clusterId, agentId, closeDialog, accountId, workspaceId, dispatch)
    return (
        <form className='activate-byol-form' onSubmit={handleSubmit(addLicense)}>
            <DefaultDialogLayout
                styleClass='active-byol-dialog'
                title={'Activate BYOL License'}
                buttonsArr={[
                    {
                        text: 'Activate license',
                        styleClass: 'primary',
                        type: 'submit',
                        thin: true,
                        loading
                    },
                    {text: 'Cancel', styleClass: 'secondary', onClick: closeDialog, thin: true, disable: loading}
                ]}
                isLoading={loading}
                errorMessage={error}>
                <div className="description">
                    This action installs a new FabricPool license on the cluster.<br/>
                    The NetApp Support Site account must be associated with the serial number that you enter.

                </div>
                <div className="license-form">
                    <div className="first-line">
                        <Field name="licenseSerialNumber"
                               className="fixed-width"
                               component={InputFieldStaticPlaceholder}
                               label="License serial number"
                               templateString="XXXXXXXXX"
                               type="text"/>
                    </div>
                    <div className="second-line">
                        <Field name="nssUsername"
                               component={InputField}
                               className="fixed-width"
                               label="NSS Username"
                               placeholder="Jhondoe"
                               type="text"/>
                        <Field name="nssPassword"
                               component={InputField}
                               className="fixed-width"
                               label="NSS Password"
                               placeholder="******"
                               type="password"/>
                    </div>

                </div>
            </DefaultDialogLayout>
        </form>
    )

};

const rules = {
    licenseSerialNumber: ['required', 'regex:/^\\d{9}$/'],
    nssUsername: 'required',
    nssPassword: 'required'
};

const validate = (values) => {
    let errors = {};
    const validator = new Validator(values, rules);
    validator.setAttributeNames({
        licenseSerialNumber: 'License Serial Number',
        nssUsername: 'NSS Username',
        nssPassword: 'NSS Password'
    });
    validator.passes();
    errors = validator.errors.all();
    return errors;
};

let ActivateByolDialogForm = reduxForm({
    form: 'activateByolLicense',
    validate
})(ActivateByolDialog);

const mapStateToProps = state => {
    return {
        accountId: state.general.accountId,
        workspaceId: state.general.workspaceId,
    };
};

export default connect(mapStateToProps)(ActivateByolDialogForm);
