import React, {useMemo} from 'react';
import NotificationWidget from "./NotificationWidget";
import {connect} from "react-redux";
import {NOTIFICATION_TYPES} from "../../utils/consts";
import {REMOVE_ERROR} from "../../actions";

require('./toasterNotification.scss');

const ToasterNotification = ({notifications, errors, dispatch}) => {
    const errorArr = useMemo(() => {
        return convertErrorMapToArr(errors, dispatch)
    }, [errors, dispatch]);

    const errorsAndNotifications = useMemo(() => [...errorArr, ...notifications], [errorArr, notifications])

    return (<div className={`toaster-notifications-wrapper`}>
        {errorsAndNotifications.map(({variant, text, id, onRemove}) => <NotificationWidget key={id}
                                                                                           className="panel-notification"
                                                                                           onRemove={onRemove}
                                                                                           variant={variant}>{text}</NotificationWidget>)}
    </div>)

}

const convertErrorMapToArr = (errorsMap, dispatch) => {
    if (!errorsMap) {
        return [];
    }
    return Object.values(errorsMap).map(({message, id}) => ({
        id,
        variant: NOTIFICATION_TYPES.ERROR,
        text: message,
        onRemove: () => {
            dispatch({type: REMOVE_ERROR, payload: id})
        }
    }))
}

const mapStateToProps = (state) => ({
    notifications: state.general.toasterNotifications,
    errors: state.errors.generalErrors
})


export default connect(mapStateToProps)(ToasterNotification);