import React from 'react';
import classNames from 'classnames';
import {connect} from 'react-redux';
import {withRouter} from 'react-router-dom';
import _ from "lodash";
import {decodeAll} from "../../utils/encoders";
import mapStateToProps from './wizardMapStateToProps';

require('./internalWizardHeader.scss');

const InternalWizardHeader = (props) => {
    return (
        <div className={classNames("internal-wizard-header", {hidden: props.wizard && props.wizard.hideHeader})}>
            <WizardSteps {...props}></WizardSteps>
        </div>
    )
}

const WizardSteps = (props) => {
    if (!props.wizard || !props.wizard.currentStep) return <div/>;
    const {wizard: {stepNames, stepNameToPathName, stepDisplayNameByProvider, currentStep, selectedWizardParams}, routing: {location}} = props;
    const {provider} = selectedWizardParams || {};

    const currentIndex = stepNames.indexOf(currentStep);
    let currentPathSegments = _.dropWhile(location.pathname.split("/"), _.isEmpty);
    currentPathSegments = _.each(currentPathSegments, segment => {
        return decodeAll(segment);
    });
    return (
        <div className="steps float-center">
            {stepNames.map((step, index) => {
                const history = props.history;
                const pathNameOfCurrentIndex = stepNameToPathName[step];
                const pathIndexOfCurrentIndex = currentPathSegments.indexOf(pathNameOfCurrentIndex);
                const search = window.location.search;
                // console.log(`%c header mapping current search is ${JSON.stringify(search, null, 2)}`, 'font-weight:bold;color:green');
                const goBack = index < currentIndex ? () => {
                    // console.log(`%c goBack current search is ${JSON.stringify(search, null, 2)}`, 'font-weight:bold;color:purple');
                    const fixedSearch = search ? (search + "&down=true") : '?down=true';
                    history.push("/" + _.take(currentPathSegments, pathIndexOfCurrentIndex + 1).join("/") + fixedSearch);
                } : undefined;
                const stepDisplayName = stepDisplayNameByProvider[step] && stepDisplayNameByProvider[step][provider] ? stepDisplayNameByProvider[step][provider] : step;
                return (<WizardStep goBack={goBack} key={`${step}-${index}`} current={currentIndex === index}
                                    future={currentIndex < index} stepName={stepDisplayName} stepNumber={index}
                                    last={index === (stepNames.length - 1)}/>)
            })}
        </div>
    )
}

const WizardStep = (props) => {
    const {stepName, current, future, goBack} = props;
    const classes = classNames({
        step: true,
        current,
        future,
        past: !current && !future
    });
    return (
        <div className={classes}>
            <button type="button" className={classNames({disabled: !goBack})} onClick={goBack ? goBack : _.noop()}>
                <span className="step-name">{stepName}</span>
                {current && <div className="active-block"></div>}
            </button>
        </div>
    )
}

export default connect(mapStateToProps)(withRouter(InternalWizardHeader));
