import React, {Component} from 'react';
import {connect} from 'react-redux';
import {Route, Switch} from 'react-router-dom';
import {WIZARD_START_WIZARD} from '../../actions'
import SourceVolumesStep from '../tierVolumes/SourceVolumesStep'
import mapStateToProps from './wizardMapStateToProps'
import _ from 'lodash';
import SetupBucketStep from "../setupClusterWizard/SetupBucketStep"
import SetupCredentialsStep from "../setupClusterWizard/SetupCredentialsStep"
import SetupIpSpaceStep from '../setupClusterWizard/SetupIpSpaceStep'
import SetupStorageClassStep from '../setupClusterWizard/SetupStorageClassStep';
import SetupBucketStepAzure from '../setupClusterWizard/SetupBucketStepAzure';
import SetupStorageClassStepAzure from '../setupClusterWizard/SetupStorageClassStepAzure';
import StorageGridStep from '../setupClusterWizard/StorageGridStep';
import SetupBucketStepSG from '../setupClusterWizard/SetupBucketStepSG';
import { PROVIDER_TYPE_AWS, PROVIDER_TYPE_AZURE, PROVIDER_TYPE_GCP, PROVIDER_TYPE_SGWS } from '../../utils/consts';
import ResourceGroupStep from "../setupClusterWizard/ResourceGroupStep";

export const calculateNextStep = (wizard, forCurrentStep) => {
    const currentStepIndex = wizard.stepNames.indexOf(forCurrentStep || wizard.currentStep);
    const nextStepName = wizard.stepNames[currentStepIndex + 1];
    // console.log(`%c calculateNextStep currentStep=${wizard.currentStep}, curStepIndex=${currentStepIndex} nextStepName=${nextStepName}`, "font-weight: bold; color: purple");
    return wizard.stepNameToPathName[nextStepName];
};

export const calculateLastStepPath = (wizard, forCurrentStep) => {
    const currentStepIndex = wizard.stepNames.indexOf(forCurrentStep || wizard.currentStep);
    const lastStepName = wizard.stepNames[currentStepIndex - 1];
    return wizard.stepNameToPathName[lastStepName];
};

export const getNextStepComponent = (nextStep) => {
    switch (nextStep) {
//new wizard
        case "setup-bucket": return SetupBucketStep;
        case "setup-bucket-azure": return SetupBucketStepAzure;
        case "setup-bucket-sg": return SetupBucketStepSG;
        case "setup-storage-class": return SetupStorageClassStep;
        case "setup-storage-class-azure": return SetupStorageClassStepAzure;
        case "setup-credentials": return SetupCredentialsStep;
        case "setup-ip-space": return SetupIpSpaceStep;
        case "setup-server": return StorageGridStep;
        case "resource-group": return ResourceGroupStep;
        default: {
            throw new Error(`Unknown step ${nextStep}`);
        }
    }
};


const wizards = {
    steps: {
        setup: ['Setup Bucket', 'Setup Storage Class', 'Setup Credentials', 'Setup IP Space'],
        "setup-sg": ['Setup Storage Grid','Setup Bucket SG', 'Setup IP Space'],
        "setup-azure": ['Resource Group','Setup Bucket Azure', 'Setup Storage Class Azure', 'Setup IP Space'],
        "tier-volumes": ["Source Volumes"]

    },
    stepNameToPathName: {
//new wizard
        setup: {
            'Setup Bucket': 'setup-bucket',
            'Setup Storage Class': 'setup-storage-class',
            'Setup Credentials': 'setup-credentials',
            'Setup IP Space': 'setup-ip-space'
        },
        "setup-sg": {
            'Setup Storage Grid': 'setup-server',
            'Setup Bucket SG': 'setup-bucket-sg',
            'Setup IP Space': 'setup-ip-space'
        },
        "setup-azure": {
            'Setup Bucket Azure': 'setup-bucket-azure',
            'Setup Storage Class Azure': 'setup-storage-class-azure',
            'Setup Credentials': 'setup-credentials',
            'Setup IP Space': 'setup-ip-space',
            'Resource Group': 'resource-group'
        },
        "tier-volumes": {
            'Source Volumes': 'volumes'
        }
    },
    stepDisplayNameByProvider: {
        'Setup Storage Grid': {[PROVIDER_TYPE_SGWS.name]: 'Server'},
        'Setup Bucket': {[PROVIDER_TYPE_AWS.name] : 'S3 Bucket', [PROVIDER_TYPE_GCP.name]: 'Bucket'},
        'Setup Bucket SG': {[PROVIDER_TYPE_SGWS.name]: 'Bucket'},
        'Setup Bucket Azure': {[PROVIDER_TYPE_AZURE.name]: 'Azure Container'},
        'Setup Storage Class': {[PROVIDER_TYPE_AWS.name]: 'Storage Class', [PROVIDER_TYPE_GCP.name]: 'Storage Class'},
        'Setup Storage Class Azure': {[PROVIDER_TYPE_AZURE.name]: 'Access Tier'},
        'Setup Credentials': {[PROVIDER_TYPE_AWS.name]: 'Credentials', [PROVIDER_TYPE_GCP.name]: 'Credentials'},
        'Setup IP Space': {[PROVIDER_TYPE_AWS.name]: 'Cluster Network', [PROVIDER_TYPE_GCP.name]: 'Cluster Network',
            [PROVIDER_TYPE_SGWS.name]:'Cluster Network', [PROVIDER_TYPE_AZURE.name]: 'Cluster Network'}
    }
};

class WizardStarter extends Component {
    constructor(props, context) {
        super(props, context);
        const {match, wizard, data} = props;
        if (match.isExact || !wizard) {
            const clusterId = props.match.params.clusterId;
            const {wizardType, clusters} = data;
            const wizardCluster = _.find(clusters, {clusterId});
            this.props.startWizard(wizardType, wizardCluster,wizards.steps[wizardType],wizards.stepNameToPathName[wizardType], wizards.stepDisplayNameByProvider);
        }
    }


    render() {
        return (
            <Switch>
                <Route path={`/setup/:clusterId/:clusterName/:agentId/:provider/setup-bucket`} render={(props) => <SetupBucketStep {...props}/>}/>
                <Route path={`/setup-sg/:clusterId/:clusterName/:agentId/:provider/setup-server`} render={(props) => <StorageGridStep {...props}/>}/>
                <Route path={`/setup-azure/:clusterId/:clusterName/:agentId/:provider/resource-group`} render={(props) => <ResourceGroupStep {...props}/>}/>
                <Route path={`/tier-volumes/:clusterId/:clusterName/volumes`} render={(props) => <SourceVolumesStep{...props}/>}/>
            </Switch>
        )
    }
}

const mapDispatchToProps = dispatch => {
    return {
        startWizard: (wizardType, wizardCluster, stepNames, stepNameToPathName, stepDisplayNameByProvider) => {
            dispatch({
                type: WIZARD_START_WIZARD,
                payload: {
                    wizardType,
                    wizardCluster,
                    stepNames,
                    stepNameToPathName,
                    stepDisplayNameByProvider
                }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(WizardStarter);
