import {removeStartingAndEndingSlash} from '../../utils/encoders';
import _ from 'lodash';
import {calculateLastStepPath} from './WizardStarter';

const mapStateToProps = (state, ownProps) => {
    const addWizardParams = (mappedState, ownProps) => {
        if (!mappedState.wizard ||
            !mappedState.wizard.currentStep ||
            !ownProps.match ||
            !ownProps.match.params) {
            return mappedState;
        }
        const {stepNameToPathName, currentStep, updatedSelectedWizardParams} = mappedState.wizard;
        //remove beginning slash and ending slash
        const currentPath = removeStartingAndEndingSlash(ownProps.location.pathname);

        const currentPathSegments = currentPath.split('/');

        const currentStepPath = stepNameToPathName[currentStep];
        const currentStepIndexInUrl = currentPathSegments.indexOf(currentStepPath);
        const nextPath = currentStepIndexInUrl > -1 ? currentPathSegments.slice(0, currentStepIndexInUrl + 1).join('/') : currentPath;
        // console.log(`%c wizardMapStateToProps\ncurrentStep: ${currentStep}\ncurrentStepPath: ${currentStepPath}\nnextPath: ${nextPath}`, 'font-weight:bold; color:orange');


        const lastStepPath = calculateLastStepPath(mappedState.wizard, currentStep);
        const lastStepIndexInUrl = currentPathSegments.indexOf(lastStepPath);
        const lastPath = currentStepIndexInUrl > -1 ? currentPathSegments.slice(0, lastStepIndexInUrl + 1).join('/') : currentPath;
        // console.log(`%c wizardMapStateToProps\ncurrentStep: ${currentStep}\nlastStepPath: ${lastStepPath}\nlastPath: ${lastPath}`, 'font-weight:bold; color:orange');

        const nextStep = (suffix, history) => {
            history.push(`/${nextPath}${suffix}${history.location.search}`);
        };

        const lastStep = (history) => {
            history.push(`/${lastPath}${history.location.search}`);
        };

        const {appRouting: {routingInfo: {urlParams: {decodedParams}}}} = state;
        mappedState.wizard = mappedState.wizard.set('nextStep', nextStep).set('lastStep', lastStep).updateIn(['selectedWizardParams'], currentParams => _.merge(currentParams, decodedParams, updatedSelectedWizardParams));
        // console.log(`%c%%%%%%%%%%%\nselectedWizardParams:${JSON.stringify(mappedState.wizard.selectedWizardParams)}\nupdatedWizardParams:${JSON.stringify(updatedSelectedWizardParams)}\n%%%%%%%%%%%%%%%%%%%`, 'font-weight:bold;color:blue');
        return mappedState;
    };

    return addWizardParams({
        wizard: state.wizardReducer.wizard,
        routing: state.router,
        routingInfo: state.appRouting.routingInfo,
        accountId: state.general.accountId,
        agentId: state.general.agentId,
        workspaceId: state.general.workspaceId,
    }, ownProps);
};

export default mapStateToProps;
