import {gql} from '@apollo/client';
import {
    CLUSTER_FRAGMENT,
    LICENSE_INFO_FRAGMENT,
    VOLUME_FRAGMENT,
    AGGREGATE_FRAGMENT
} from './fragments';


//queries

export const
    GET_CLUSTERS_QUERY = gql`
        query($accountId: ID!, $agentId:ID!, $workspaceId:ID!){
            clusters(accountId:$accountId, agentId:$agentId, workspaceId:$workspaceId) {
                ...clusterFields
            }
        }
    ${CLUSTER_FRAGMENT}`;

export const
    GET_LAZY_CLUSTERS_QUERY = gql`
        query($accountId: ID!, $agentId:ID!, $workspaceId:ID!){
            lazyClusters(accountId:$accountId, agentId:$agentId, workspaceId:$workspaceId) {
                ...clusterFields
            }
        }
    ${CLUSTER_FRAGMENT}`;

export const
    GET_CLUSTER_QUERY = gql`
        query($clusterId: ID!, $accountId:ID!, $agentId:ID, $workspaceId:ID){
            cluster(clusterId: $clusterId, accountId: $accountId,agentId:$agentId, workspaceId:$workspaceId) {
                ...clusterFields
            }
        }
    ${CLUSTER_FRAGMENT}`;

export const GET_REGIONS_AND_BUCKETS_G_QUERY = gql`
    query($cloudProvider: CLOUD_PROVIDERS!,$accountId: ID,$agentId: ID, $clusterId: ID!, $request: GetBucketsRequest){
        regions(cloudProvider: $cloudProvider,accountId:$accountId, agentId: $agentId, clusterId: $clusterId){
            code
            name,
        },
        bucketsG(request: $request) {
            ...on BucketG {
                name
            }
            ...on CloudBucket {
                name
                region {
                    code
                    name
                }
            }
            ...on SGBucket {
                name
            }
        }
    }`;

export const GET_CONTAINERS = gql`
    query($request: GetBucketsRequest){
        bucketsG(request: $request) {
            ...on AzureContainer {
                name
                region {
                    code
                    name
                }
                storageAccount
            }
        }
    }`;

export const GET_STORAGE_ACCOUNTS = gql`
    query($accountId:ID, $agentId: ID!, $resourceGroupName: ID!){
        storageAccounts(accountId:$accountId, agentId:$agentId, resourceGroupName:$resourceGroupName){
            resourceGroup,
            name,
            region {
                code
                name
            }
        },
    }`;

export const GET_BUCKETS_G_QUERY = gql`
    query($request: GetBucketsRequest){
        bucketsG(request: $request) {
            ...on BucketG {
                name
            }
            ...on CloudBucket {
                name
                region {
                    code
                    name
                }
            }
            ...on SGBucket {
                name
            }
        }
    }`;

export const GET_REGIONS_QUERY = gql`
    query($cloudProvider: CLOUD_PROVIDERS!,$accountId: ID, $clusterId: ID, $agentId: ID){
        regions(cloudProvider: $cloudProvider, accountId:$accountId, clusterId: $clusterId, agentId: $agentId){
            code
            name
        }
    }`;

export const GET_IP_SPACES_QUERY = gql`
    query($accountId: ID, $clusterId: ID!, $agentId: ID, $workspaceId:ID){
        ipSpaces(accountId:$accountId, clusterId: $clusterId, agentId: $agentId, workspaceId:$workspaceId)
    }`;

export const GET_VOLUMES_QUERY = gql`
    query ($accountId: ID, $agentId:ID, $clusterId: ID!, $workspaceId:ID) {
        volumes(accountId:$accountId, agentId:$agentId clusterId: $clusterId, workspaceId:$workspaceId){
            ...volumeFields
        }
    }${VOLUME_FRAGMENT}
`;

export const GET_AGGREGATES_QUERY = gql`
    query ($accountId: ID,$agentId:ID, $clusterId: ID!, $workspaceId:ID) {
        aggregates(accountId:$accountId, agentId:$agentId, clusterId: $clusterId, workspaceId:$workspaceId){
            ...aggregateFields
        }
    }${AGGREGATE_FRAGMENT}
`;

export const GET_LICENSE_INFO_QUERY = gql`
    query ($accountId: ID){
        licenseInfo(accountId:$accountId){
            ...licenseInfoFields
        }
    }${LICENSE_INFO_FRAGMENT}`;

export const GET_RESOURCE_GROUP = gql`
    query ($accountId: ID, $agentId:ID!){
        resourceGroups(accountId:$accountId,agentId:$agentId){
            name
        }
    }`;

//mutations

export const MODIFY_VOLUMES = gql`
    mutation ($accountId: ID,$agentId:ID, $clusterId: ID!, $volumeProperties: [VolumeProperties!]!, $workspaceId:ID) {
        modifyVolumes(input : {accountId:$accountId, agentId:$agentId, clusterId: $clusterId, volumeProperties: $volumeProperties, workspaceId:$workspaceId}) {
            data {name svmName tieringPolicy minimumCoolingDays isTiered}
            errors {reason name svmName}
        }
    }
`;

export const MODIFY_AGGREGATES = gql`
    mutation ($accountId: ID, $agentId:ID, $clusterId: ID!, $aggregatesProperties: [AggregateProperties!]!, $workspaceId:ID) {
        modifyAggregates(input : {accountId:$accountId,agentId:$agentId, clusterId: $clusterId, aggregatesProperties: $aggregatesProperties, workspaceId:$workspaceId}) {
            data {name idr tieringFullnessThreshold}
            errors {reason name}
        }
    }
`;

export const VERIFY_PERMISSIONS = gql`
    mutation ($accountId: ID, $credentials: Keys, $cloudProvider: CLOUD_PROVIDERS!, $bucket: String!, $region: String!) {
        verifyPermissions( input: {
            accountId:$accountId
            credentials: $credentials
            cloudProvider: $cloudProvider
            bucket: $bucket
            region: $region
        }) { status }
    }
`;

export const REMOVE_CLUSTER = gql`
    mutation ($accountId: ID, $agentId: ID, $clusterId: ID, $workspaceId:ID) {
        removeCluster( input: {
            accountId:$accountId
            clusterId: $clusterId
            agentId: $agentId
            workspaceId:$workspaceId
        }) { status }
    }
`;

export const SETUP_CLUSTER_G = gql`
    mutation ($cloudProvider:CLOUD_PROVIDERS!, $aws : S3SetupTiering, $gcp: GcpSetupTiering, $azure:AzureSetupTiering, $sgws: SgwsSetupTiering) {
        setupClusterTieringG ( input: {cloudProvider: $cloudProvider,aws: $aws,gcp: $gcp,azure: $azure,sgws: $sgws}) { status }
    }
`;

export const SETUP_CLUSTER_G2 = gql`
    mutation ($cloudProvider:CLOUD_PROVIDERS!, $aws : S3SetupTiering, $gcp: GcpSetupTiering, $azure:AzureSetupTiering, $sgws: SgwsSetupTiering) {
        setupClusterTieringG2 ( input: {cloudProvider: $cloudProvider,aws: $aws,gcp: $gcp,azure: $azure,sgws: $sgws}) {
            clusterId
            tierInformation {
                bucketName
                providerType
                objectStoreName
                regionName
                tierLevel
                currentSavings {
                    cost
                    capacity
                }
            }
        }
    }
`;

export const CREATE_BUCKET_G = gql`
    mutation ($cloudProvider : CLOUD_PROVIDERS!, $aws:CreateAwsBucket, $gcp: CreateGcpBucket, $sgws:CreateSgwsBucket, $azure: CreateAzureContainer) {
        createBucketG(input: {cloudProvider: $cloudProvider, aws: $aws, gcp: $gcp, sgws: $sgws, azure: $azure}) { status }
    }
`;

export const CHANGE_TIER_LEVEL_G = gql`
    mutation ($cloudProvider:CLOUD_PROVIDERS!, $aws:ChangeAwsTierLevelRequest, $gcp: ChangeGCPTierLevelRequest, $azure:ChangeAzureTierLevelRequest) {
        changeTierLevelG(input: {cloudProvider: $cloudProvider, aws: $aws, gcp: $gcp, azure:$azure}) { status }
    }
`;

export const APPLY_BYOLL_LICENSE = gql`
    mutation ($input:applyByolLicenseInput!) {
        applyByolLicense(input: $input) { status }
    }
`

//subscriptions

export const UPDATE_LICENSE_INFO = gql`
    subscription ($accountId: ID)
    {
        licenseInfo(accountId: $accountId) {
            ...licenseInfoFields
        }
    }${LICENSE_INFO_FRAGMENT}`;

export const UPDATE_CLUSTER_INFO = gql`
    subscription ($accountId: ID!, $agentId:ID!, $resourceType: RESOURCE_TYPE, $workspaceId:ID!)
    {
        clusterInfo(accountId: $accountId, agentId:$agentId, resourceType:$resourceType, workspaceId:$workspaceId) {
            ...clusterFields
        }
    }${CLUSTER_FRAGMENT}`;

