import React from 'react';
import Isvg from 'react-inlinesvg';

export const CLUSTER_STATUS = {
    ON: 'ON',
    FAILED: 'FAILED',
    UNKNOWN: 'UNKNOWN',
    NO_TIERING: 'NO_TIERING'
};

export const FEATURE_STATE = {
    NOT_SUPPORTED: 'not_supported',
    EDITABLE: 'editable',
    READONLY: 'read_only'
};

export const TIER_BUTTON_TEXT = {
    'setup': 'SET UP TIERING',
    'volumes': 'TIER VOLUMES'
};

export const PROVIDER_TYPE_AWS = {
    name: 'AWS',
    displayName: 'AWS',
    icon: <span className="aws"><Isvg src={require(`./../assets/svgs/aws-color.svg`)}/></span>,
    licenseIcon: <span className="provider-icon"><Isvg src={require(`./../assets/svgs/aws-icon.svg`)}/></span>,
    mpURL: process.env.REACT_APP_MP_URL_AWS,
    subscriptionURL: 'https://docs.netapp.com/us-en/cloud-tiering/task_licensing.html#subscribe-aws'
};

export const PROVIDER_TYPE_AZURE = {
    name: 'AZURE',
    displayName: 'Azure',
    icon: <span className="azure"><Isvg src={require(`./../assets/svgs/azure-color.svg`)}/></span>,
    licenseIcon: <span className="provider-icon"><Isvg src={require(`./../assets/svgs/azure-icon.svg`)}/></span>,
    mpURL: process.env.REACT_APP_MP_URL_AZURE,
    subscriptionURL: 'https://docs.netapp.com/us-en/cloud-tiering/task_licensing.html#subscribe-azure'
};

export const PROVIDER_TYPE_GCP = {
    name: 'GCP',
    displayName: 'GCP',
    icon: <span className="gcp"><Isvg src={require(`./../assets/svgs/gcp-color.svg`)}/></span>,
    licenseIcon: <span className="provider-icon"><Isvg src={require(`./../assets/svgs/gcp-icon.svg`)}/></span>,
    mpURL: process.env.REACT_APP_MP_URL_GCP,
    subscriptionURL: 'https://docs.netapp.com/us-en/cloud-tiering/task_licensing.html#subscribe-gcp'
};

export const PROVIDER_TYPE_SGWS = {
    name: 'SGWS',
    displayName: 'StorageGRID',
    icon: <span className="sg"><Isvg src={require(`./../assets/svgs/sg-color.svg`)}/></span>,
    licenseIcon: <span className="provider-icon"><Isvg src={require(`./../assets/svgs/sg-icon.svg`)}/></span>,
    soon: true
};

export const BYOL = {
    licenseCardLogo: <span className="aws"><Isvg src={require(`./../assets/svgs/byol-license-card-logo.svg`)}/></span>,
    licenseIcon: <span className="provider-icon"><Isvg src={require(`./../assets/svgs/byol-icon.svg`)}/></span>
};

export const PROVIDERS = {
    [PROVIDER_TYPE_AWS.name]: PROVIDER_TYPE_AWS,
    [PROVIDER_TYPE_AZURE.name]: PROVIDER_TYPE_AZURE,
    [PROVIDER_TYPE_GCP.name]: PROVIDER_TYPE_GCP,
    [PROVIDER_TYPE_SGWS.name]: PROVIDER_TYPE_SGWS
};

export const DASHBOARD_TITLES = {
    dataNotAvailable: 'No Available Data',
    notTiered: 'Cold data has not been tiered yet',
    allTiered: 'Data tiering is enabled on all volumes',
    estimated: 'The cold data is an estimate based on industry standards. We estimate that 70% of the data in the performance tier is cold data that you can move to lower-cost object storage. For ONTAP 9.4 and later, Cloud Tiering replaces the estimate with a precise value, as soon as it discovers more information about the system. The discovery period is approximately 31 days.'
};

export const DASHBOARD_FILTER_TYPE = {
    "all": "All",
    "ON_PREM": "On-prem",
    "CVO": "Cloud Volumes ONTAP"
};

export const VOLUMES_STEP_INFO = {
    DISPLAYED_VOLUMES: <span><h5>Displayed Volumes</h5>The total number of volumes that Cloud Tiering displays might be less than the number of volumes on your ONTAP system. That's because some volumes can't be tiered. For example, you can't tier data from SnapLock volumes or from MetroCluster configurations. Refer to ONTAP Documentation for features not supported by FabricPool.</span>,
    USED_SIZE: <span><h5>Used Size</h5>The amount of space occupied by user data and file system metadata.</span>,
    COLD_DATA:
        <span><h5>Cold Data</h5>The amount of inactive data on the volume that you can tier to object storage.</span>,
    COLD_DATA_ESTIMATED: <span><h5>Cold Data (Estimated Amount)</h5>The amount of inactive data on the volume that you can tier to object storage. {DASHBOARD_TITLES.estimated}</span>
};

export const MANAGE_AGGREGATES_INFO = {
    DISPLAYED_AGGREGATES: <span><h5>Displayed Aggregate</h5>The total number of aggregates that Cloud Tiering displays might be less than the number of aggregates on your ONTAP system. That’s because some aggregates can’t be configure for tiering. For example, you can’t configure tiering for root aggregate. Refer to ONTAP Documentation for features not supported by FabricPool.</span>,
    USED_SIZE: <span><h5>Used Size</h5>The amount of space occupied by user data and file system metadata.</span>,
    COLD_DATA:
        <span><h5>Cold Data</h5>The amount of inactive data on the volume that you can tier to object storage.<br/><br/><h5>Estimated cold Data</h5>The cold data is an estimate based on industry standards. We estimate that 70% of the data in the performance tier is cold data that you can move to lower-cost object storage. For ONTAP 9.4 and later, Cloud Tiering replaces the estimate with a precise value, as soon as it discovers more information about the system. The discovery period is approximately 31 days.</span>,
    FULLNESS_THRESHOLD: <span><h5>Tiering Fullness Threshold</h5>Setting the threshold to a lower number reduces the amount of data required to be stored on the performance tier before tiering takes place. This may be useful for large aggregates that contain little hot/active data.<br/><br/>Setting the threshold to a higher number increases the amount of data required to be stored on the performance tier before tiering takes place. This may be useful for solutions designed to tier only when aggregates are near maximum capacity.</span>,
    IDR: <span><h5>IDR benefits</h5>Inactive Data Report uses a 31-day cooling period to determine what data is considered inactive. The amount of cold data that is tiered is dependent on the tiering policies set on volumes. This amount might be different than the amount of cold data detected by IDR using a 31-day cooling period</span>
};

export const LICENSE_PAGE_INFO = {
    LICENSE: <span><h5>License</h5>The current license configuration related to the cluster. After your free trial, the license configuration can include bringing your own license (BYOL), or pay-as-you-go license, or a combination of both.</span>
};

export const AGENT_STATUS = {
    pending: {
        status: 'pending',
        display: 'Pending',
        order: 2
    },
    active: {
        status: 'active',
        display: 'Online',
        order: 1
    },
    inactive: {
        status: 'inactive',
        display: 'Offline',
        order: 3
    },
    unknown: {
        status: 'unknown',
        display: 'Unknown',
        order: 5
    }
};

export const AGENT_NAME = 'Connector';


export const STORAGE_CLASSES = {
    [PROVIDER_TYPE_AWS.name]: [
        {
            storageClassName: 'Standard-Infrequent Access',
            storageClass: 'standard_ia'
        },
        {
            storageClassName: 'Standard',
            storageClass: 'standard'
        },
        {
            storageClassName: 'One Zone-IA',
            storageClass: 'ia_single'
        },
        {
            storageClassName: 'Intelligent',
            storageClass: 'intelligent'
        }
    ],
    [PROVIDER_TYPE_AZURE.name]: [
        {
            storageClassName: 'Hot',
            storageClass: 'hot'
        },
        {
            storageClassName: 'Cool',
            storageClass: 'cool'
        }
    ],
    [PROVIDER_TYPE_GCP.name]: [{
        storageClassName: 'Standard',
        storageClass: 'standard'
    }]
};

export const DEFAULT_STORAGE_CLASS = 0;

export const TIERING_SETUP_TITLES = {
    [PROVIDER_TYPE_AWS.name]: {
        title1: <div className="step-title-info">Cloud Tiering will create an AWS Bucket that will store the tiered
            data.<br/>
            Make sure that there is a connection between the on-prem cluster that you selected and the S3 bucket.</div>,
        title1existing: <div className="step-title-info">Make sure that there is a connection between the on-prem
            cluster that you selected and the S3 bucket.</div>,
        title2: <div className="step-title-info">We can apply a lifecycle rule so the data transitions from the Standard
            storage class to another storage class after 30 days. Keep Standard selected if you don’t want to transition
            the data. Refer to
            <a href="https://aws.amazon.com/s3/storage-classes/" target="_blank" rel="noopener noreferrer"> AWS
                documentation </a> for more details.</div>,
        title3: <div className="step-title-info">
            Providing your keys is secure and private. Cloud Tiering does not save them.<br/>
            Make sure that your AWS account has the permission defined in the
            <a href="https://docs.netapp.com/us-en/cloud-tiering/task_preparing.html#preparing-aws-s3-for-data-tiering"
               target="_blank" rel="noopener noreferrer"> Policy Requirements
            </a>
        </div>
    },
    'ONPREM': {
        title1: <div className="step-title-info">Cloud Tiering can create an AWS Bucket that will store the tiered
            data.</div>,
        title2: <div className="step-title-info">We will add transition Lifecycle Management rule of the selected
            storage class to this bucket. Refer to
            <a href="https://aws.amazon.com/s3/storage-classes/" target="_blank" rel="noopener noreferrer"> AWS
                documentation </a> for more details about S3 storage classes.</div>,
        title3: <div className="step-title-info">
            Providing your keys is secure and private. Cloud Tiering does not save them.<br/>
            Make sure that your AWS account has the permission defined in the<br/>
            <a href="https://docs.netapp.com/us-en/cloud-tiering/task_preparing.html#preparing-aws-s3-for-data-tiering"
               target="_blank" rel="noopener noreferrer"> Policy Requirements
            </a>
        </div>
    },
    [PROVIDER_TYPE_AZURE.name]: {
        title1: <div className="step-title-info">Cloud Tiering can create an Azure container that will store the tiered
            data.</div>,
        title2: <div className="step-title-info">Choose an access tier for the tiered data and all other Blob containers
            in the selected storage account. Important : This selection applies to all Blob containers in the selected
            storage account. Refer to
            <a href="https://docs.microsoft.com/en-us/azure/storage/blobs/storage-blob-storage-tiers" target="_blank"
               rel="noopener noreferrer"> Azure documentation </a> for more details about Access Tier.
        </div>
    },
    [PROVIDER_TYPE_GCP.name]: {
        title1: <div className="step-title-info">Cloud Tiering will create a GCP Bucket that will store the tiered data.<br/>
            Make sure that there is a connection between the on-prem cluster that you selected and the bucket.</div>,
        title1existing: <div className="step-title-info">Make sure that there is a connection between the on-prem
            cluster that you selected and the bucket.</div>,
        title2: <div className="step-title-info">We’ll associate the tiered data with the storage class that you select.<br/> Refer
            to
            <a href="https://cloud.google.com/storage/docs/storage-classes" target="_blank"
               rel="noopener noreferrer"> GCP documentation </a> for more details about storage classes.
        </div>,
        title3: <div className="step-title-info">
            Providing your keys is secure and private, Cloud Tiering does not save them.<br/>
            Make sure that your GCP account has the permission defined in the<br/>
            <a
                href="https://docs.netapp.com/us-en/cloud-tiering/task_preparing_google.html"
                target="_blank" rel="noopener noreferrer"> Policy Requirements
            </a>
        </div>
    },
    [PROVIDER_TYPE_SGWS.name]: {
        title1: <div className="step-title-info">Cloud Tiering will create a {PROVIDER_TYPE_SGWS.displayName} Bucket
            that will store the tiered data.<br/>
            Make sure that there is a connection between the on-prem cluster that you selected and the bucket.</div>,
        title1existing: <div className="step-title-info">Make sure that there is a connection between the on-prem
            cluster that you selected and the bucket.</div>,
        title3: <div className="step-title-info">
            Providing your keys is secure and private, Cloud Tiering does not save them.<br/>
            Make sure that your {PROVIDER_TYPE_SGWS.displayName} account has the permission defined in the<br/>
            <a
                href="https://docs.netapp.com/us-en/cloud-tiering/task_preparing_google.html"
                target="_blank" rel="noopener noreferrer"> Policy Requirements
            </a>
        </div>
    }

};

export const TIERING_POLICY_NONE = {
    name: 'none',
    displayName: 'No Policy',
    description: 'No Policy',
    minimumCoolingDays: 0
};

export const TIERING_POLICY = {
    'auto': {
        name: 'auto',
        displayName: 'Auto',
        description: 'Cold user data & snapshots',
        title: 'Tiers cold user data and snapshot copies',
        details: <span>The Cold User Data tiers all cold blocks in the volume to object storage. Data is tiered only after an aggregate has reached 50% capacity and when the data has reached the cooling period, which is approximately 31 days.<br/><br/>Based on industry standards, we estimate that 70% of the data on this system is cold data that you can tier to low-cost object storage. For ONTAP 9.4 and later, Cloud Tiering replaces the estimate with a precise value after approximately 31 days.</span>,
        notSupportedBelow: 9.4,
        notSupportedVersionIcon: 'ontap-v9-4-icon.svg',
        notSupportedTitle: 'Supported with ONTAP 9.4 and later',
        icon: 'auto-tiering-policy.svg',
        order: 2,
        mostPopular: true
    },
    'snapshot_only': {
        name: 'snapshot_only',
        displayName: 'Snapshot-Only',
        description: 'Cold snapshots',
        title: 'Tiers cold Snapshot copies.',
        details: 'The Snapshot Only policy tiers cold user data blocks of Snapshot copies that are not associated with the active file system to object storage. Data is tiered only after an aggregate has reached 50% capacity and when the data has reached the cooling period, which is approximately 2 days.',
        icon: 'snapshot-policy.svg',
        order: 1
    },
    'backup': {
        name: 'backup',
        displayName: 'Backup',
        description: 'All DP user data',
        title: 'Backup for DP volumes',
        details: 'All data (not including metadata) is immediately moved to the cloud tier. If read, cold data blocks on the cloud tier stay cold and are not written back to the performance tier (starting with ONTAP 9.4). You can assign this policy to data protection volumes only.',
        icon: 'backup-policy.svg',
        order: 3
    },
    'all': {
        name: 'all',
        displayName: 'All',
        description: 'All user data',
        title: 'Backup for DP volumes above specific version',
        details: 'All data (not including metadata) is immediately moved to the cloud tier. If read, cold data blocks on the cloud tier stay cold and are not written back to the performance tier.',
        icon: 'all-policy.svg',
        notSupportedBelow: 9.6,
        notSupportedTitle: 'Supported with ONTAP 9.6 and later',
        order: 4
    }
};
export const TIERING_POLICY_AVAILABLE_INFO = <span>The total number of volumes that Cloud Tiering displays might be less than the number of volumes on your ONTAP system. That's because some volumes can't be tiered. For example, you can't tier data from SnapLock volumes or from MetroCluster configurations. Refer to
                                            <a href="https://docs.netapp.com/ontap-9/index.jsp?topic=%2Fcom.netapp.doc.dot-cm-psmg%2FGUID-8E421CC9-1DE1-492F-A84C-9EB1B0177807.html"
                                               target="_blank" rel="noopener noreferrer"> ONTAP Documentation
                                            </a>
                                            for features not supported by FabricPool.
                                        </span>;

export const DOCUMENTATION_URL = 'https://docs.netapp.com/us-en/cloud-tiering/index.html';
export const FREE_TRIAL_PERIOD = 30;
export const WARNING_FREE_TRIAL_PERIOD = 7;
export const DEFAULT_IP_SPACE = 'Default';

export const PRE_FREE_TRIAL = 'PRE';
export const FREE_TRIAL = 'STARTED';
export const FREE_TRIAL_WARNING = 'WARNING';
export const FREE_TRIAL_EXPIRED = 'EXPIRED';
export const SUBSCRIBED = 'subscribed';
export const UNSUBSCRIBED = 'unsubscribed';

export const MAX_VOLUMES_IN_PAGE = 50;

export const SUPPORT_REGISTERED = 'registered';
export const SUPPORT_IN_PROGRESS = 'in_progress';
export const SUPPORT_NOT_REGISTERED = 'not_registered';

export const SUPPORT_TICKET_URL = 'https://mysupport.netapp.com/portal?_nfpb=true&_st=initialPage=true&_pageLabel=submitcase';
export const SUPPORT_PHONE = 'https://www.netapp.com/us/contact-us/support.aspx';
export const SALES = 'https://www.netapp.com/us/forms/sales-contact.aspx';
export const COMMUNITIES = 'https://community.netapp.com/t5/Cloud-Data-Services/ct-p/CDS';
export const FAQ = ' https://docs.netapp.com/us-en/cloud-tiering/faq.html';

export const SETUP_COMPLETE = 'SETUP_COMPLETE';
export const VOLUMES_TIERING_COMPLETE = 'VOLUMES_TIERING_COMPLETE';

export const SERVICE_CONNECTIVITY_FAILED = 'FAILED';
export const SERVICE_CONNECTIVITY_SUCCESS = 'SUCCESS';

export const PAYGO = 'pay-as-you-go';

export const LOCAL_AUTO_DISCOVER_ERRORS = ['INVALID_CREDENTIALS', 'INVALID_ROLE', 'NO_ADMIN_ROLE', 'NOT_ELIGIBLE', 403];

export const MAX_COOLING_DAYS = 63;
export const MIN_COOLING_DAYS = 2;
export const COOLING_DAYS_INFO = 'The cooling period is the time that user data in a volume must remain inactive before it is considered "cold" and moved to object storage';

export const MAX_TIERING_FULLNESS_THRESHOLD = 100;
export const MIN_TIERING_FULLNESS_THRESHOLD = 1;
export const TIERING_FULLNESS_THRESHOLD_INFO = <div><h4>Tiering Fullness Threshold</h4>Setting the threshold to a lower
    number
    reduces the amount of data required to be stored on the performance tier before tiering takes place.
    This may be useful for large aggregates that contain little hot/active data.<br/>
    Setting the threshold to a higher number increases the amount of data required to be stored on the performance tier
    before tiering takes place. This may be useful for solutions designed to tier only when aggregates are near maximum
    capacity.
    capacity</div>;
export const TIERING_IDR_INFO = <div><h4>IDR Benefits</h4>Inactive data reporting (IDR) uses a 31-day cooling period to
    determine which data is considered inactive. The amount of cold data
    that is tiered is dependent on the tiering policies set on volumes. This amount might be different than the amount
    of cold data detected by IDR using a 31-day cooling period.</div>;

export const NOTIFICATION_TITLES = {
        header: 'We\'ve made improvements that requires a new Cloud Manager',
        belowHeader: 'The improvements to Cloud Tiering requires you to deploy a new Cloud Manager and rediscover your working environments.',
        contact: 'Contact us if you need help with deploying a new Cloud Manager and rediscovering your working environments.',
        mailto: 'ng-cloud-tiering@netapp.com',
        subject: 'I need help with deploying a new Cloud Manager and rediscoverning my working environments',
        message: ''
};

export const NOTIFICATION_ERROR_CODE = 'NO_VALID_AGENTS';

export const IP_REG_EXP = /^(\\d|[1-9]\\d|1\\d\\d|2([0-4]\\d|5[0-5]))\\.(\\d|[1-9]\\d|1\\d\\d|2([0-4]\\d|5[0-5]))\\.(\\d|[1-9]\\d|1\\d\\d|2([0-4]\\d|5[0-5]))\\.(\\d|[1-9]\\d|1\\d\\d|2([0-4]\\d|5[0-5]))$/;
export const HOST_NAME_REG_EXP = /^(([a-zA-Z]|[a-zA-Z][a-zA-Z0-9-]*[a-zA-Z0-9])\.)*([A-Za-z]|[A-Za-z][A-Za-z0-9-]*[A-Za-z0-9])$/;
export const KEYS_REG_EXP = /^[ -~]+$/g;
export const HOST_IPV4_IPV6_REG_EXP = /((^\s*((([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5]))\s*$)|(^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*$))|(^\s*((?=.{1,255}$)(?=.*[A-Za-z].*)[0-9A-Za-z](?:(?:[0-9A-Za-z]|\b-){0,61}[0-9A-Za-z])?(?:\.[0-9A-Za-z](?:(?:[0-9A-Za-z]|\b-){0,61}[0-9A-Za-z])?)*)\s*$)/;

export const NOTIFICATION_TYPES = {
    SUCCESS: 'SUCCESS',
    WARNING: 'WARNING',
    ERROR: 'ERROR'
}
