import React from 'react';
import {Link} from "react-router-dom";
import {FREE_TRIAL_EXPIRED, PROVIDER_TYPE_SGWS, SUBSCRIBED} from "./consts";

const FreeTrialEnforcement = ({agentCloudProvider, clusterId}) => {
    return (<>
        <Link to={`/license?open=paygo:${agentCloudProvider}`}>Subscribe to {agentCloudProvider} Marketplace</Link>
        {` or `}
        <Link to={`/license?open=byol:${clusterId}`}>activate BYOL license</Link>
    </>)
}

const ByolEnforcement = ({agentCloudProvider}) => {
    return (<>
        To continue tiering,{` `}
        <Link to={`/license?open=paygo:${agentCloudProvider}`}>subscribe to {agentCloudProvider} MP with PAYGGO</Link>
    </>)
}

export const getEnforcementInfo = (licenseInfo) => {
    const enforcementInfo = {reason: "", ActionComp: () => null, shouldEnforce: false};
    if (!licenseInfo) return enforcementInfo;
    const {shouldEnforce, byolCapacity: maxCapacity, currentCapacity, freeTrialStatus, subscriptionStatus, hasBYOL} = licenseInfo;
    enforcementInfo.shouldEnforce = shouldEnforce
    if (!hasBYOL && freeTrialStatus === FREE_TRIAL_EXPIRED && subscriptionStatus !== SUBSCRIBED) {
        enforcementInfo.reason = "Your free trial has ended";
        enforcementInfo.ActionComp = FreeTrialEnforcement;
    } else if (hasBYOL && currentCapacity > maxCapacity && subscriptionStatus !== SUBSCRIBED) {
        enforcementInfo.reason = `You have exceeded your license capacity.`;
        enforcementInfo.ActionComp = ByolEnforcement;
    }
    return enforcementInfo;
};

export const checkShouldEnforce = (cluster) => {
    if (cluster.agentCloudProvider === 'ONPREM' && !cluster.tierInformation) {
        return false
    }
    if (cluster.licenseInfo?.provider === PROVIDER_TYPE_SGWS.name) {
        return false
    }
    return cluster.licenseInfo?.shouldEnforce
}